/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_omA5KCpe);
  numBytes += sLine_init(&sLine_q55rIIQu);
  numBytes += sLine_init(&sLine_RXuwQDqx);
  numBytes += sLine_init(&sLine_U43hhlwT);
  numBytes += sLine_init(&sLine_XNI4RVFg);
  numBytes += sBiquad_init(&sBiquad_s_oRlDI940);
  numBytes += sLine_init(&sLine_3BRyh3aq);
  numBytes += sLine_init(&sLine_zFY4KbZe);
  numBytes += sLine_init(&sLine_jcGwNiJH);
  numBytes += sLine_init(&sLine_32jhpGSq);
  numBytes += sBiquad_init(&sBiquad_s_T3t9qKX4);
  numBytes += sLine_init(&sLine_AYuQ1App);
  numBytes += sLine_init(&sLine_8RhhWQvf);
  numBytes += sLine_init(&sLine_LaHhP2Z2);
  numBytes += sLine_init(&sLine_VhlTNYj1);
  numBytes += sLine_init(&sLine_RWVVlYj2);
  numBytes += sBiquad_init(&sBiquad_s_NC2UYpbC);
  numBytes += sLine_init(&sLine_F0ko72bF);
  numBytes += sLine_init(&sLine_8IJ9l0fM);
  numBytes += sLine_init(&sLine_hNvBSVUl);
  numBytes += sLine_init(&sLine_OroIV9lu);
  numBytes += sLine_init(&sLine_8ZdQz8YU);
  numBytes += sBiquad_init(&sBiquad_s_a0EBFV1X);
  numBytes += sLine_init(&sLine_wDNEl99D);
  numBytes += sLine_init(&sLine_9xMHmRlp);
  numBytes += sLine_init(&sLine_1n3h4wAe);
  numBytes += sLine_init(&sLine_nkFvphH8);
  numBytes += sBiquad_init(&sBiquad_s_Pv6tt6Rf);
  numBytes += sLine_init(&sLine_HgcRTfkJ);
  numBytes += sLine_init(&sLine_eyntfMig);
  numBytes += sLine_init(&sLine_M2nAZxzn);
  numBytes += sLine_init(&sLine_yiFINTHQ);
  numBytes += sLine_init(&sLine_fRKVhMgZ);
  numBytes += sBiquad_init(&sBiquad_s_uP1Enq5k);
  numBytes += sLine_init(&sLine_Qca1B6tO);
  numBytes += sTabread_init(&sTabread_cDDUNJrW, &hTable_8HPMpveJ, true);
  numBytes += sLine_init(&sLine_Ld81jzZc);
  numBytes += sLine_init(&sLine_SJhBnlC3);
  numBytes += sTabread_init(&sTabread_XSVARinO, &hTable_XbXIcMtB, true);
  numBytes += sLine_init(&sLine_T967aA45);
  numBytes += sRPole_init(&sRPole_9SGRvcpm);
  numBytes += sDel1_init(&sDel1_r6WN5A7I);
  numBytes += sTabwrite_init(&sTabwrite_VrlnEtB7, &hTable_8HPMpveJ);
  numBytes += sRPole_init(&sRPole_PAhqg6mO);
  numBytes += sDel1_init(&sDel1_EoEdRl1c);
  numBytes += sTabwrite_init(&sTabwrite_UipxQ9Q2, &hTable_XbXIcMtB);
  numBytes += sLine_init(&sLine_dcvx6aMT);
  numBytes += sLine_init(&sLine_yohbZYcF);
  numBytes += sRPole_init(&sRPole_2Mwdk09a);
  numBytes += sEnv_init(&sEnv_3NM8vyFY, 1024, 512);
  numBytes += sRPole_init(&sRPole_VJkyzgxk);
  numBytes += sLine_init(&sLine_HSonlW4E);
  numBytes += sLine_init(&sLine_DKrV1FLI);
  numBytes += sRPole_init(&sRPole_xDfdw80J);
  numBytes += sEnv_init(&sEnv_3Ur5xe5Q, 1024, 512);
  numBytes += sRPole_init(&sRPole_7iXdq632);
  numBytes += sLine_init(&sLine_NqvJu6LU);
  numBytes += sTabread_init(&sTabread_CX3DdD67, &hTable_FCBqCvS2, true);
  numBytes += sLine_init(&sLine_1iWzq5fB);
  numBytes += sLine_init(&sLine_702bVxoo);
  numBytes += sTabread_init(&sTabread_I5GDdxiY, &hTable_FwVkR2wI, true);
  numBytes += sLine_init(&sLine_WRbfQt8y);
  numBytes += sRPole_init(&sRPole_b2swAmbm);
  numBytes += sDel1_init(&sDel1_pbAyNHyP);
  numBytes += sTabwrite_init(&sTabwrite_72VoPxid, &hTable_FCBqCvS2);
  numBytes += sRPole_init(&sRPole_lHbncL31);
  numBytes += sDel1_init(&sDel1_sWxa3gO1);
  numBytes += sTabwrite_init(&sTabwrite_tcC5eXT9, &hTable_FwVkR2wI);
  numBytes += sLine_init(&sLine_KTRiXuvp);
  numBytes += sLine_init(&sLine_lyaalCbg);
  numBytes += sRPole_init(&sRPole_DFTmD5KJ);
  numBytes += sEnv_init(&sEnv_exOBYnSR, 1024, 512);
  numBytes += sRPole_init(&sRPole_wS3gwc26);
  numBytes += sLine_init(&sLine_KK3vuWZW);
  numBytes += sLine_init(&sLine_GRLPEUIu);
  numBytes += sRPole_init(&sRPole_OBg8S9Rj);
  numBytes += sEnv_init(&sEnv_ZZdJf1AB, 1024, 512);
  numBytes += sRPole_init(&sRPole_8iAI62Kh);
  numBytes += sLine_init(&sLine_DAJBLTqD);
  numBytes += sTabread_init(&sTabread_xJH4vOog, &hTable_G6f7aeBB, true);
  numBytes += sLine_init(&sLine_CpgWRXLl);
  numBytes += sLine_init(&sLine_gefE6pUA);
  numBytes += sTabread_init(&sTabread_bb6jcpBr, &hTable_VqXDdzKs, true);
  numBytes += sLine_init(&sLine_xaaTCYiE);
  numBytes += sRPole_init(&sRPole_pizf7C07);
  numBytes += sDel1_init(&sDel1_rkWnf1Jn);
  numBytes += sTabwrite_init(&sTabwrite_JXLLQdQ2, &hTable_G6f7aeBB);
  numBytes += sRPole_init(&sRPole_WFjHfnZo);
  numBytes += sDel1_init(&sDel1_4YrkIPHW);
  numBytes += sTabwrite_init(&sTabwrite_LO96Zn0Q, &hTable_VqXDdzKs);
  numBytes += sLine_init(&sLine_aveJ4Zj1);
  numBytes += sLine_init(&sLine_DJFVV6DT);
  numBytes += sRPole_init(&sRPole_mfiopNmy);
  numBytes += sEnv_init(&sEnv_3J942x7F, 1024, 512);
  numBytes += sRPole_init(&sRPole_ICzgsh0f);
  numBytes += sLine_init(&sLine_EX5eOTSR);
  numBytes += sLine_init(&sLine_Y7LjO1OI);
  numBytes += sRPole_init(&sRPole_gdwOm5GA);
  numBytes += sEnv_init(&sEnv_0f4SMEK6, 1024, 512);
  numBytes += sRPole_init(&sRPole_8PStfZAP);
  numBytes += cVar_init_f(&cVar_C0DcBSow, 0.0f);
  numBytes += cVar_init_f(&cVar_uLKVU2DG, 0.0f);
  numBytes += cVar_init_f(&cVar_LbQ7P5d6, 0.0f);
  numBytes += cVar_init_f(&cVar_hSRcDpZG, 0.0f);
  numBytes += cSlice_init(&cSlice_zNe65CwJ, 1, -1);
  numBytes += cVar_init_f(&cVar_4YRJbCzH, 1337.0f);
  numBytes += cVar_init_f(&cVar_vmc5wlcm, 0.0f);
  numBytes += cIf_init(&cIf_y0OLcSJP, false);
  numBytes += cIf_init(&cIf_cOMQq7AB, false);
  numBytes += cBinop_init(&cBinop_uqL25WLf, 0.0f); // __pow
  numBytes += cIf_init(&cIf_xDQh5pzC, false);
  numBytes += cBinop_init(&cBinop_oR9MdpMC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JXVL9ksD, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_1hGDJVly, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_YUz7bndj, 0.0f);
  numBytes += cIf_init(&cIf_0WdIHyL9, false);
  numBytes += cIf_init(&cIf_8vRaVndm, false);
  numBytes += cBinop_init(&cBinop_WKzyzFoX, 0.0f); // __pow
  numBytes += cIf_init(&cIf_vGKwO6FC, false);
  numBytes += cBinop_init(&cBinop_jkwe8Ub8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_0QEPqyyR, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Vhn96S8s, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_TKf7wzxp, 0.0f);
  numBytes += cIf_init(&cIf_xIC4aZZ8, false);
  numBytes += cIf_init(&cIf_PiScP9xG, false);
  numBytes += cBinop_init(&cBinop_Z7xGYftF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Gf3nEy4R, false);
  numBytes += cBinop_init(&cBinop_gxTqRoyV, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ivrxbPnu, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_bMbwVyaA, -15.0f); // __eq
  numBytes += cIf_init(&cIf_0GbC0M3f, false);
  numBytes += cSlice_init(&cSlice_f18Nekql, 1, -1);
  numBytes += cVar_init_f(&cVar_nC9B0eue, 0.0f);
  numBytes += cSlice_init(&cSlice_PEckX9Pk, 1, -1);
  numBytes += cVar_init_f(&cVar_rTZIdtzE, 0.0f);
  numBytes += cSlice_init(&cSlice_ney8uBwh, 1, -1);
  numBytes += cVar_init_f(&cVar_JnjGSftv, 0.0f);
  numBytes += cSlice_init(&cSlice_eAXGTARb, 1, -1);
  numBytes += cVar_init_f(&cVar_wUvWmhak, 0.313f);
  numBytes += cBinop_init(&cBinop_swyu0311, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PZkAW6NK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WXmzUecc, 0.0f);
  numBytes += cVar_init_f(&cVar_tKJyyV7n, 1337.0f);
  numBytes += cVar_init_f(&cVar_9yaon4ck, 0.3f);
  numBytes += cBinop_init(&cBinop_YxsMxdHT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cXrHE8d4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P15XPjD3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9GI7Xzq1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ltYXSyhb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iL53rPnS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_T5ZGK7tO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JHj2mBbu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_qzeiS7pw, 0.0f);
  numBytes += cVar_init_f(&cVar_XgDvdedK, 1337.0f);
  numBytes += cVar_init_f(&cVar_FUF8sik2, 0.313f);
  numBytes += cBinop_init(&cBinop_sNHE70Or, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_13f7rft3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UlHSFMXt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IVsTaOx5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_X6G4LN0w, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TcNYkLZO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_F6IdN2zG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZcCAzttm, 0.0f);
  numBytes += cVar_init_f(&cVar_nKV3VcRg, 1037.0f);
  numBytes += cVar_init_f(&cVar_BSQnhgwv, 0.4f);
  numBytes += cBinop_init(&cBinop_rbIP2cb2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6btEgg6o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ye8L8WT1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xW2IisyH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Woug9vEv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_00l6M1Z7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mVbmpBku, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_81DZFLqG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_61nm4BUS, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_fZPDPrWm, 1, -1);
  numBytes += cVar_init_f(&cVar_zbeLt9MQ, 1337.0f);
  numBytes += cVar_init_f(&cVar_ZH3mvOl6, 0.0f);
  numBytes += cIf_init(&cIf_EIlR86Gh, false);
  numBytes += cIf_init(&cIf_zamV18li, false);
  numBytes += cBinop_init(&cBinop_lDbciaYM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AVsIU56O, false);
  numBytes += cBinop_init(&cBinop_oUVg5SGS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HfKCcfg4, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3HBiquQO, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_E3t3wJ69, 0.0f);
  numBytes += cIf_init(&cIf_vDfcGWmU, false);
  numBytes += cIf_init(&cIf_pbGl7MCn, false);
  numBytes += cBinop_init(&cBinop_5rFLGV6B, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5HEb7TP7, false);
  numBytes += cBinop_init(&cBinop_Ikgxi4wA, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wB990Ou2, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_UXqArws0, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hjdgief4, 0.0f);
  numBytes += cIf_init(&cIf_oEDfoxuM, false);
  numBytes += cIf_init(&cIf_h0uMxfPX, false);
  numBytes += cBinop_init(&cBinop_IRGJoeaK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_MCQQImcD, false);
  numBytes += cBinop_init(&cBinop_DxlUMPsn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JiPxEEHE, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Zkc9tq4c, -15.0f); // __eq
  numBytes += cIf_init(&cIf_JNz3bG4k, false);
  numBytes += cSlice_init(&cSlice_mAj00J5m, 1, -1);
  numBytes += cVar_init_f(&cVar_WYaVSJZJ, 0.0f);
  numBytes += cSlice_init(&cSlice_OxxUFolh, 1, -1);
  numBytes += cVar_init_f(&cVar_k4l5hAQf, 0.0f);
  numBytes += cSlice_init(&cSlice_CzMo0pwU, 1, -1);
  numBytes += cVar_init_f(&cVar_wx5RiGQ8, 0.0f);
  numBytes += cSlice_init(&cSlice_HhoPMnNO, 1, -1);
  numBytes += cVar_init_f(&cVar_8oSTuWTx, 0.313f);
  numBytes += cBinop_init(&cBinop_EyuDZMSu, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Q3tbVbQG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Jhjm27T8, 0.0f);
  numBytes += cVar_init_f(&cVar_MtWe9rhZ, 1337.0f);
  numBytes += cVar_init_f(&cVar_7xqJmUBz, 0.3f);
  numBytes += cBinop_init(&cBinop_VoPqS4fM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1kYsppk2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QtOmAHdM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OiOA2bD6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ntVM66QB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TvbSNGX8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pdro3a4j, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_f5ztFp6b, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_aS658AFQ, 0.0f);
  numBytes += cVar_init_f(&cVar_opwa3kVl, 1337.0f);
  numBytes += cVar_init_f(&cVar_MKq98he7, 0.313f);
  numBytes += cBinop_init(&cBinop_CcHBnVmp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MBZmrFIS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FS5JGx72, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AP3N7oKL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hUrxS80k, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NIqlVN9K, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_yMgruy8d, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_beSpTc54, 0.0f);
  numBytes += cVar_init_f(&cVar_eCbJiEmn, 1037.0f);
  numBytes += cVar_init_f(&cVar_Bao1AIbJ, 0.4f);
  numBytes += cBinop_init(&cBinop_nQx4FhwP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ocVOF5yF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LRoTbPss, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SSZ9tDod, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8nYtrCCV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4qgaUIom, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_uhrbE4A6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0C0Hnj1D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a6VLjl42, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_o2dGWIcQ, 5705.6f);
  numBytes += cVar_init_f(&cVar_PIVPAuaJ, 313.3f);
  numBytes += cBinop_init(&cBinop_x7UeCkmp, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_8xnGXJCa, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_2poHrky5, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_mFyE8y3s, 0.0f);
  numBytes += cVar_init_f(&cVar_FxKZEaJw, 0.0f);
  numBytes += cVar_init_f(&cVar_TABzL5ZJ, 0.0f);
  numBytes += cVar_init_f(&cVar_cSlNmWNZ, 0.0f);
  numBytes += cVar_init_f(&cVar_7NfHwQ3h, 0.0f);
  numBytes += cVar_init_f(&cVar_MTW3ogoh, 0.0f);
  numBytes += cVar_init_f(&cVar_VdM4AORz, 0.0f);
  numBytes += cVar_init_f(&cVar_m0iZefOe, 0.0f);
  numBytes += cVar_init_f(&cVar_YRLRlpmK, 0.0f);
  numBytes += cVar_init_f(&cVar_SOxiB8GN, 0.0f);
  numBytes += cVar_init_f(&cVar_Mx6pdwcA, 0.0f);
  numBytes += cVar_init_f(&cVar_ecEMUUNV, 0.0f);
  numBytes += cSlice_init(&cSlice_yrVZqAAS, 1, -1);
  numBytes += cVar_init_f(&cVar_B3gSS8LD, 0.5f);
  numBytes += cSlice_init(&cSlice_XrBPz12y, 1, -1);
  numBytes += cVar_init_f(&cVar_D70C9Ciw, 0.2f);
  numBytes += cSlice_init(&cSlice_1EssAy0r, 1, -1);
  numBytes += cVar_init_f(&cVar_fc0jQ8vp, 500.0f);
  numBytes += sVarf_init(&sVarf_gXg8aEzO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_tzOVxEew, 600.0f);
  numBytes += cBinop_init(&cBinop_3Rr8GpvG, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_FdrK9cjG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XbliOmNJ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_W3nVsx9n, 600.0f);
  numBytes += cBinop_init(&cBinop_8w9Kw4V3, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_ij7U779I, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rezjnfAt, 4000.0f);
  numBytes += cBinop_init(&cBinop_pEfoD93Z, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qm81l0ZA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GwQwkNMg, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_I4DDkla0, 4000.0f);
  numBytes += cBinop_init(&cBinop_eQMLjUtX, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ETdThg09, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XDmyN7U0, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_OwzaKlXn, false);
  numBytes += cBinop_init(&cBinop_axNf8wiW, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_8hOp9xqw, 20.0f);
  numBytes += cBinop_init(&cBinop_GH6HKora, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_MrllREA8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c5GKq47s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1fhR3Fi8, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_z6UZCqPY, false);
  numBytes += cBinop_init(&cBinop_5kAYNnbM, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_ddNAi7O6, 20.0f);
  numBytes += cBinop_init(&cBinop_WguIvRDd, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_64sZ3ziu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Kc4xE38x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2vs4YYz0, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_c7uD0Sx5, 1, -1);
  numBytes += cVar_init_f(&cVar_jW2QKe1t, 0.25f);
  numBytes += cDelay_init(this, &cDelay_NSlmspRs, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ifT5vfuB, 0.0f);
  numBytes += hTable_init(&hTable_8HPMpveJ, 256);
  numBytes += cTabhead_init(&cTabhead_F4GtTbIr, &hTable_8HPMpveJ);
  numBytes += cVar_init_s(&cVar_iS1RJB7L, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_JAB625bp, 0.0f);
  numBytes += cDelay_init(this, &cDelay_O1MsYHVG, 0.0f);
  numBytes += cBinop_init(&cBinop_pbsmgdOr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QsLjjppo, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_x35Tjxlx, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_THrpNLPk, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_gKvpVmBK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ohby44aQ, 0.0f);
  numBytes += hTable_init(&hTable_XbXIcMtB, 256);
  numBytes += cTabhead_init(&cTabhead_kauJ8r1J, &hTable_XbXIcMtB);
  numBytes += cVar_init_s(&cVar_Uwarmot4, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_J4paqwOg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_N4BE0u8b, 0.0f);
  numBytes += cBinop_init(&cBinop_izPin5kW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GM4SvBTy, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_UEPeO9b8, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_8mP47vnN, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_cOsg6KrM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iHQL8um3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_19VdkH0V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_I0DqX5Ua, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_3BdVXcZj, 1, -1);
  numBytes += cVar_init_f(&cVar_274n9S7T, 0.5f);
  numBytes += cSlice_init(&cSlice_hUW1BZnF, 1, -1);
  numBytes += cVar_init_f(&cVar_iWxVhMIJ, 0.2f);
  numBytes += cSlice_init(&cSlice_IwWnix50, 1, -1);
  numBytes += cVar_init_f(&cVar_DiQ3Qca1, 500.0f);
  numBytes += sVarf_init(&sVarf_Hl2VWnF0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gSD8t8XO, 600.0f);
  numBytes += cBinop_init(&cBinop_nkT2iyBP, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_6KXxTGnk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KhRYLDTl, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_fpxTmhQB, 600.0f);
  numBytes += cBinop_init(&cBinop_t5XTIhOi, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_pr06Jslp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_WunJiGUG, 4000.0f);
  numBytes += cBinop_init(&cBinop_64pzUSgs, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_viTTaNIf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gYAC76SU, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PBay6eda, 4000.0f);
  numBytes += cBinop_init(&cBinop_lgcZB3lG, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DT1rW6L0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Kv7rY4Hf, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_dxmBtjJr, false);
  numBytes += cBinop_init(&cBinop_Xd5XAx3o, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_DnEgOjpa, 20.0f);
  numBytes += cBinop_init(&cBinop_LOYJCaHa, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FbS1wYDV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yHhqifyN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NeLd2ecQ, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_2quMAYGF, false);
  numBytes += cBinop_init(&cBinop_vse6Vs1T, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_17aBEsbG, 20.0f);
  numBytes += cBinop_init(&cBinop_m7BwMjLo, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_omidDxOV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0IHZNvvW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7cr0nyxy, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_88s5lHee, 1, -1);
  numBytes += cVar_init_f(&cVar_zFlf2zdf, 0.25f);
  numBytes += cDelay_init(this, &cDelay_LR9aJ9O7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y6kQldqa, 0.0f);
  numBytes += hTable_init(&hTable_FCBqCvS2, 256);
  numBytes += cTabhead_init(&cTabhead_dneQWYhC, &hTable_FCBqCvS2);
  numBytes += cVar_init_s(&cVar_zgdgXT1x, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_mW6fLdjc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_C4fAz1CY, 0.0f);
  numBytes += cBinop_init(&cBinop_rdF1B6xJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Iw0Rxw0a, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_y5m1XVPs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_P1P4Y6MT, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_cp8FYcgK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_kwhCUjqI, 0.0f);
  numBytes += hTable_init(&hTable_FwVkR2wI, 256);
  numBytes += cTabhead_init(&cTabhead_OyhPKcdz, &hTable_FwVkR2wI);
  numBytes += cVar_init_s(&cVar_xpGSKRxr, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_9cbeGmXl, 0.0f);
  numBytes += cDelay_init(this, &cDelay_z2GBqii6, 0.0f);
  numBytes += cBinop_init(&cBinop_beuJeVO9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3c73CuIE, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_vQivYBT7, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_d9T5yXEz, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_o6EklrDZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RKwwVbn7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nz5NOcqJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G2K3Tots, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_087D8NX3, 1, -1);
  numBytes += cVar_init_f(&cVar_dleIlgbh, 0.5f);
  numBytes += cSlice_init(&cSlice_6mQIDiky, 1, -1);
  numBytes += cVar_init_f(&cVar_bJrmdpAL, 0.2f);
  numBytes += cSlice_init(&cSlice_IfCluGMB, 1, -1);
  numBytes += cVar_init_f(&cVar_o7ARrhsv, 500.0f);
  numBytes += sVarf_init(&sVarf_JGXmGjsr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Do1AHElv, 600.0f);
  numBytes += cBinop_init(&cBinop_c9nsf6f2, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_FqBwC6vH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HHgyGoGd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1R6WlJjl, 600.0f);
  numBytes += cBinop_init(&cBinop_El6p2kqL, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_skYCdhEk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lAJr7jSD, 4000.0f);
  numBytes += cBinop_init(&cBinop_XblSYjgc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DzTf67KN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Fa84xRqF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MJPhbEM7, 4000.0f);
  numBytes += cBinop_init(&cBinop_7auaTMNu, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_YqLtNHxp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EAbArrXN, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_hbYwnGrk, false);
  numBytes += cBinop_init(&cBinop_EfAe3rAa, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_R8ijNSGF, 20.0f);
  numBytes += cBinop_init(&cBinop_xHvDvyNr, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fO5dTPqW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WSvvMDPA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vnU1Vbeq, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_DrPl9oaF, false);
  numBytes += cBinop_init(&cBinop_6NZqrXWE, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_71ph0P71, 20.0f);
  numBytes += cBinop_init(&cBinop_iD5sxJlI, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_xk6yv0BX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Tn44PTZY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MkV5Iacq, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_59IL3JJF, 1, -1);
  numBytes += cVar_init_f(&cVar_yI3FDjQ2, 0.25f);
  numBytes += cDelay_init(this, &cDelay_RZjqOCwr, 0.0f);
  numBytes += cDelay_init(this, &cDelay_XVbRIi0H, 0.0f);
  numBytes += hTable_init(&hTable_G6f7aeBB, 256);
  numBytes += cTabhead_init(&cTabhead_qXWlE18p, &hTable_G6f7aeBB);
  numBytes += cVar_init_s(&cVar_x8G2Hh9l, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_R1Zg6NOg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UhCQtDw6, 0.0f);
  numBytes += cBinop_init(&cBinop_uqZ1iRLc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SEEJ8Fns, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_lXkUK9wg, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_iRWvw0Eb, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_WCF235um, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Btseitex, 0.0f);
  numBytes += hTable_init(&hTable_VqXDdzKs, 256);
  numBytes += cTabhead_init(&cTabhead_3pln0vBJ, &hTable_VqXDdzKs);
  numBytes += cVar_init_s(&cVar_ZC14BOwJ, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_0Xye5bQk, 0.0f);
  numBytes += cDelay_init(this, &cDelay_iOzwORbo, 0.0f);
  numBytes += cBinop_init(&cBinop_wWt8LC0c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VWmPMVp6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_nEJ4A4E6, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_gdh5tDgN, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_kENnCArN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8U1S45Bk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RK7mYsxZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CGDnSy6q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xiBAKdhL, 1.0f);
  numBytes += cIf_init(&cIf_6CBiguP2, false);
  numBytes += cIf_init(&cIf_AC3wq2By, false);
  numBytes += cVar_init_f(&cVar_I3DfDTZT, 0.0f);
  numBytes += cVar_init_f(&cVar_CLpMpKLc, 0.0f);
  numBytes += cVar_init_f(&cVar_a6BnBNzz, 1.0f);
  numBytes += cIf_init(&cIf_jgQ1XDPk, false);
  numBytes += cIf_init(&cIf_NoIzcgDu, false);
  numBytes += cVar_init_f(&cVar_3mcONFon, 0.0f);
  numBytes += cVar_init_f(&cVar_KSGdD5qD, 0.0f);
  numBytes += cVar_init_f(&cVar_DJSxkS4W, 1.0f);
  numBytes += cIf_init(&cIf_5QLoZxWb, false);
  numBytes += cIf_init(&cIf_hXrzVZze, false);
  numBytes += cVar_init_f(&cVar_lCA77H95, 0.0f);
  numBytes += cVar_init_f(&cVar_UyGm4Nt6, 0.0f);
  numBytes += cVar_init_f(&cVar_57swfCAl, 60000.0f);
  numBytes += cVar_init_f(&cVar_9sAcgJIC, 500.0f);
  numBytes += cSlice_init(&cSlice_Ht9SZzUL, 1, -1);
  numBytes += cSlice_init(&cSlice_ox5GMiPZ, 1, -1);
  numBytes += cVar_init_f(&cVar_Ph8PIg4B, 0.0f);
  numBytes += cIf_init(&cIf_CTJOjTJ3, false);
  numBytes += cBinop_init(&cBinop_1wB4uRWR, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_JlLuT7l9, 120.0f);
  numBytes += cBinop_init(&cBinop_4l7PYbLz, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Hykyih0Y, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZtcIXQiM, 60000.0f);
  numBytes += cVar_init_f(&cVar_PuxHlg54, 500.0f);
  numBytes += cSlice_init(&cSlice_NvROmE2s, 1, -1);
  numBytes += cSlice_init(&cSlice_gF1FlKxl, 1, -1);
  numBytes += cVar_init_f(&cVar_vRCJKta2, 0.0f);
  numBytes += cIf_init(&cIf_TlKjoT4N, false);
  numBytes += cBinop_init(&cBinop_sFR7fzxC, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_8BnTrS62, 120.0f);
  numBytes += cBinop_init(&cBinop_JtfPChHB, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_EK5doNd5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FBxlZ5Cy, 60000.0f);
  numBytes += cVar_init_f(&cVar_Y830kcCq, 500.0f);
  numBytes += cSlice_init(&cSlice_c7ZziEYw, 1, -1);
  numBytes += cSlice_init(&cSlice_dwKWpcJK, 1, -1);
  numBytes += cVar_init_f(&cVar_hdSYiuKW, 0.0f);
  numBytes += cIf_init(&cIf_kpW0deOu, false);
  numBytes += cBinop_init(&cBinop_w7fS9EWq, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_UJB5aUF2, 120.0f);
  numBytes += cBinop_init(&cBinop_Vyk3byPC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_GtsrzKru, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ZxFvLpXk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iQaL2WTC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OmNj7kHk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G3TknXFq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VB4p1ilO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UiPtzDXG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cigMSjpS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rGjQCoTH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dYXvFRNE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aKqpr7ve, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_3NM8vyFY);
  sEnv_free(&sEnv_3Ur5xe5Q);
  sEnv_free(&sEnv_exOBYnSR);
  sEnv_free(&sEnv_ZZdJf1AB);
  sEnv_free(&sEnv_3J942x7F);
  sEnv_free(&sEnv_0f4SMEK6);
  hTable_free(&hTable_8HPMpveJ);
  hTable_free(&hTable_XbXIcMtB);
  hTable_free(&hTable_FCBqCvS2);
  hTable_free(&hTable_FwVkR2wI);
  hTable_free(&hTable_G6f7aeBB);
  hTable_free(&hTable_VqXDdzKs);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_8HPMpveJ; // del-1349-delayL
    case 0x19A00729: return &hTable_XbXIcMtB; // del-1349-delayR
    case 0x584C8281: return &hTable_FCBqCvS2; // del-1428-delayL
    case 0x54BF59F6: return &hTable_FwVkR2wI; // del-1428-delayR
    case 0xBCE693A: return &hTable_G6f7aeBB; // del-1507-delayL
    case 0x95A380B3: return &hTable_VqXDdzKs; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_udUbLD2F_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iINKZIfV_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8vPfhSEk_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sMoqqg5s_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IVnUSJ6a_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_46oO5Ee0_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XIn4OsEw_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TuXzVDve_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Kc4ymUDb_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aKM34gtU_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0FLxji4r_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cWk7AOZ7_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mk9GcxLb_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qeKyqvfA_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YJgxefG7_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1hEm6m01_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TUQ1VOlh_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4PFlWFeG_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kslNsfMc_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l99pvkhR_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qBtf0Knx_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8VuGocOQ_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FNsbLg4o_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gaCgzBFp_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KaiVidYW_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZJ1hffs1_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KPP9Xphw_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jzpHmyMh_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NVKxyP2C_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UkfaOgXv_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4nv2tkmO_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K4TOxKd5_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OG2oqp04_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_70uR3XUi_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nziBQju7_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k6dH5fXB_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xHQ9pm7P_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_edXfK5lj_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2hFLgozJ_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FzXIJSMD_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pH6TlMzr_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SJgIOV4l_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cRvsu54X_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FNmEHAgC_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FveH3am0_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P27XG5Og_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_O6rWZGEp_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jl2F20Kz_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PA49Fwzi_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VV7w97yK_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wHvued1x_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xyn50kgF_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dtbg7JaI_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zphpTjim_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hLfnkFAC_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KGh0Llek_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W0JlXdxJ_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OK3WIORE_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kCZB0hcO_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iWeTv5Ej_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DktlemJo_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QgiHht3N_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bgWhw8ze_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OK95eVkk_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_C0DcBSow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rQt4NqOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_uLKVU2DG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q16uaZlk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LbQ7P5d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lWJPq67V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hSRcDpZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wug8Ng79_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DjsGvkl2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K4qAMt1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_srovxlQ9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3ddrYabY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zNe65CwJ, 0, m, &cSlice_zNe65CwJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_y3CKczBy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zNe65CwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8frbxb4v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8frbxb4v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_4YRJbCzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8frbxb4v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_8frbxb4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KaiVidYW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vmc5wlcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jj1VM0d4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_y0OLcSJP, 0, m, &cIf_y0OLcSJP_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_y0OLcSJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TTQPWFJl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_cOMQq7AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CAUKrYmJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Nahnr0GP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_oSVEiUTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uqL25WLf, HV_BINOP_POW, 0, m, &cBinop_uqL25WLf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uqL25WLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xDQh5pzC, 0, m, &cIf_xDQh5pzC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d2j3ufjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_SnEz9MGS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e3wkwVtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nph1LRRk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_15ipf1p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cOMQq7AB, 0, m, &cIf_cOMQq7AB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nph1LRRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cOMQq7AB, 1, m, &cIf_cOMQq7AB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nahnr0GP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_d2j3ufjU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CAUKrYmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_xDQh5pzC, 0, m, &cIf_xDQh5pzC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SnEz9MGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uqL25WLf, HV_BINOP_POW, 1, m, &cBinop_uqL25WLf_sendMessage);
  cMsg_oSVEiUTR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_xDQh5pzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mVbmpBku, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_jj1VM0d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y0OLcSJP, 1, m, &cIf_y0OLcSJP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TTQPWFJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JXVL9ksD, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JXVL9ksD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1hGDJVly, HV_BINOP_EQ, 1, m, &cBinop_1hGDJVly_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1G7Me4oO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oR9MdpMC, HV_BINOP_ADD, 0, m, &cBinop_oR9MdpMC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oR9MdpMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e3wkwVtJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_15ipf1p7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JXVL9ksD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xDQh5pzC, 1, m, &cIf_xDQh5pzC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1hGDJVly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ETG05qUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ETG05qUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mVbmpBku, m);
}

void Heavy_WSTD_DL3Y::cCast_CG0bXJbr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oR9MdpMC, HV_BINOP_ADD, 1, m, &cBinop_oR9MdpMC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JXVL9ksD, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JXVL9ksD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1hGDJVly, HV_BINOP_EQ, 0, m, &cBinop_1hGDJVly_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F99zfszB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vmc5wlcm, 0, m, &cVar_vmc5wlcm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F6oDhYtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1G7Me4oO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YUz7bndj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u4rozFUn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0WdIHyL9, 0, m, &cIf_0WdIHyL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_0WdIHyL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Xj7g2f8V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_8vRaVndm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_djyxf9H7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7l4tGfRX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_uA28tN3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WKzyzFoX, HV_BINOP_POW, 0, m, &cBinop_WKzyzFoX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WKzyzFoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGKwO6FC, 0, m, &cIf_vGKwO6FC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eSpqPOel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_U6W0SdOr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_E3OAMJYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vRaVndm, 0, m, &cIf_8vRaVndm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_22f2xT2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Tuhtnp6J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tuhtnp6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vRaVndm, 1, m, &cIf_8vRaVndm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7l4tGfRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_eSpqPOel_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_djyxf9H7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vGKwO6FC, 0, m, &cIf_vGKwO6FC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U6W0SdOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WKzyzFoX, HV_BINOP_POW, 1, m, &cBinop_WKzyzFoX_sendMessage);
  cMsg_uA28tN3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_vGKwO6FC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W2DppEM9_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MXfRy7Hx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YjBgR74c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_u4rozFUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0WdIHyL9, 1, m, &cIf_0WdIHyL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xj7g2f8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0QEPqyyR, HV_BINOP_GREATER_THAN, 1, m, &cBinop_0QEPqyyR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vhn96S8s, HV_BINOP_EQ, 1, m, &cBinop_Vhn96S8s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FAV8YDii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkwe8Ub8, HV_BINOP_ADD, 0, m, &cBinop_jkwe8Ub8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jkwe8Ub8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_22f2xT2v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E3OAMJYC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0QEPqyyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGKwO6FC, 1, m, &cIf_vGKwO6FC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vhn96S8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4KCou2Kx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_4KCou2Kx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_W2DppEM9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MXfRy7Hx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YjBgR74c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SCTOYFWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YUz7bndj, 0, m, &cVar_YUz7bndj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F0FKOkVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jkwe8Ub8, HV_BINOP_ADD, 1, m, &cBinop_jkwe8Ub8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0QEPqyyR, HV_BINOP_GREATER_THAN, 0, m, &cBinop_0QEPqyyR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vhn96S8s, HV_BINOP_EQ, 0, m, &cBinop_Vhn96S8s_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OGVvxAzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FAV8YDii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_TKf7wzxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nluV19P0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_xIC4aZZ8, 0, m, &cIf_xIC4aZZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_xIC4aZZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_moEI0Dkr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_PiScP9xG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_rwZqfsuw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GNGpT9KW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_CKmsJ4zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z7xGYftF, HV_BINOP_POW, 0, m, &cBinop_Z7xGYftF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z7xGYftF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gf3nEy4R, 0, m, &cIf_Gf3nEy4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sn0bEWq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vznKGr7F_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eh0Xbmgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xCsNv9ty_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cGb690Sy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PiScP9xG, 0, m, &cIf_PiScP9xG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xCsNv9ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PiScP9xG, 1, m, &cIf_PiScP9xG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GNGpT9KW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Sn0bEWq7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rwZqfsuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Gf3nEy4R, 0, m, &cIf_Gf3nEy4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vznKGr7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z7xGYftF, HV_BINOP_POW, 1, m, &cBinop_Z7xGYftF_sendMessage);
  cMsg_CKmsJ4zr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_Gf3nEy4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_61nm4BUS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_nluV19P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xIC4aZZ8, 1, m, &cIf_xIC4aZZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_moEI0Dkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivrxbPnu, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ivrxbPnu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMbwVyaA, HV_BINOP_EQ, 1, m, &cBinop_bMbwVyaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ksGT8Eus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gxTqRoyV, HV_BINOP_ADD, 0, m, &cBinop_gxTqRoyV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gxTqRoyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eh0Xbmgs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cGb690Sy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ivrxbPnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gf3nEy4R, 1, m, &cIf_Gf3nEy4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bMbwVyaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SCGJBYUg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_SCGJBYUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_61nm4BUS, m);
}

void Heavy_WSTD_DL3Y::cCast_tu9lUGkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ksGT8Eus_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_g1b4cn9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gxTqRoyV, HV_BINOP_ADD, 1, m, &cBinop_gxTqRoyV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ivrxbPnu, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ivrxbPnu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMbwVyaA, HV_BINOP_EQ, 0, m, &cBinop_bMbwVyaA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YZb3cpoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TKf7wzxp, 0, m, &cVar_TKf7wzxp_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_0GbC0M3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_81DZFLqG, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_8nV48HJr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_f18Nekql, 0, m, &cSlice_f18Nekql_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bWYI2gUH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_f18Nekql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_teL4vaFZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_teL4vaFZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_nC9B0eue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_teL4vaFZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_teL4vaFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FNsbLg4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_bWYI2gUH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PEckX9Pk, 0, m, &cSlice_PEckX9Pk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3ddrYabY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_PEckX9Pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lLX9W402_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lLX9W402_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_rTZIdtzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lLX9W402_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lLX9W402_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KPP9Xphw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_y3CKczBy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ney8uBwh, 0, m, &cSlice_ney8uBwh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0mKhkLCs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_ney8uBwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ckaTQjWH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ckaTQjWH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JnjGSftv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ckaTQjWH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ckaTQjWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gaCgzBFp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_0mKhkLCs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eAXGTARb, 0, m, &cSlice_eAXGTARb_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eAXGTARb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_InH8DX1X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_InH8DX1X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wUvWmhak_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_InH8DX1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_InH8DX1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZJ1hffs1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YpUDgayw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_omA5KCpe, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nP7fjLpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q55rIIQu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GTufEYAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RXuwQDqx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HoK9Nj83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U43hhlwT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ov3meSnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XNI4RVFg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hzrhbynj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gkb3CPan_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gkb3CPan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_swyu0311, HV_BINOP_DIVIDE, 1, m, &cBinop_swyu0311_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qmvkYMPX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_kIEUflB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_pMy4wpWr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S1JxqfN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_kIEUflB6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pMy4wpWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_swyu0311, HV_BINOP_DIVIDE, 0, m, &cBinop_swyu0311_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qmvkYMPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S1JxqfN9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_swyu0311_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PZkAW6NK, HV_BINOP_MULTIPLY, 1, m, &cBinop_PZkAW6NK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PZkAW6NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jY1gKO3H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yb7cl528_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_BeFoF6fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GG60glA3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_JCoMXT3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YALVczZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_B1IPqVTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_tOXtcR8w_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tOXtcR8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PZkAW6NK, HV_BINOP_MULTIPLY, 0, m, &cBinop_PZkAW6NK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r5yuVo3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Nt38SZW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Nt38SZW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0mp5aG0h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UPqJhmW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WXmzUecc, 1, m, &cVar_WXmzUecc_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WXmzUecc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1tWhwdzH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oqJSnwA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cXrHE8d4, HV_BINOP_MULTIPLY, 1, m, &cBinop_cXrHE8d4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eq3p7sj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oqJSnwA4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VkkuSbME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GbCt8nm2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GbCt8nm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P15XPjD3, HV_BINOP_MULTIPLY, 1, m, &cBinop_P15XPjD3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gXFF24FI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GI7Xzq1, HV_BINOP_MULTIPLY, 1, m, &cBinop_9GI7Xzq1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ey5zp2KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gXFF24FI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CdPLf4Bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltYXSyhb, HV_BINOP_MULTIPLY, 1, m, &cBinop_ltYXSyhb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IkxZA6BJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_utUvNd4z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_utUvNd4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iL53rPnS, HV_BINOP_MULTIPLY, 1, m, &cBinop_iL53rPnS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tKJyyV7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XUeDCFqr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_B1IPqVTD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ITHs0ej9_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9yaon4ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_r5yuVo3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jY1gKO3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_BeFoF6fD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Yb7cl528_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JCoMXT3H_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_GG60glA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UkfaOgXv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YALVczZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NVKxyP2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Per6WXMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jzpHmyMh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0mp5aG0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SR1hF2nV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SR1hF2nV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YxsMxdHT, HV_BINOP_MULTIPLY, 1, m, &cBinop_YxsMxdHT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YxsMxdHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Xqx01Z9W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xqx01Z9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Per6WXMb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1tWhwdzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AvMcxzbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AvMcxzbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KCxSvvdY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GMDjXiKb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M0uNjUxE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1pzz7sF2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eCQITAhr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eVqVBely_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cXrHE8d4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YpUDgayw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_P15XPjD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nP7fjLpH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9GI7Xzq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GTufEYAj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ltYXSyhb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HoK9Nj83_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iL53rPnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ov3meSnl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_L28TqEBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tKJyyV7n, 0, m, &cVar_tKJyyV7n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mg7EUjZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9yaon4ck, 1, m, &cVar_9yaon4ck_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KCxSvvdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_eVqVBely_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cXrHE8d4, HV_BINOP_MULTIPLY, 0, m, &cBinop_cXrHE8d4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GMDjXiKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iL53rPnS, HV_BINOP_MULTIPLY, 0, m, &cBinop_iL53rPnS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eCQITAhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P15XPjD3, HV_BINOP_MULTIPLY, 0, m, &cBinop_P15XPjD3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M0uNjUxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ltYXSyhb, HV_BINOP_MULTIPLY, 0, m, &cBinop_ltYXSyhb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1pzz7sF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9GI7Xzq1, HV_BINOP_MULTIPLY, 0, m, &cBinop_9GI7Xzq1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XUeDCFqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9yaon4ck, 0, m, &cVar_9yaon4ck_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ITHs0ej9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WXmzUecc, 0, m, &cVar_WXmzUecc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FRfdqWA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3BRyh3aq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_E97Q04b9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zFY4KbZe, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_K3YFtrx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jcGwNiJH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_a79KRX3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32jhpGSq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_aGiPp1Ha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lY2YgT2N_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lY2YgT2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T5ZGK7tO, HV_BINOP_DIVIDE, 1, m, &cBinop_T5ZGK7tO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O2AJPp2s_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_1M1m6K6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_mYc17xlV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y04mDXFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_1M1m6K6d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mYc17xlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T5ZGK7tO, HV_BINOP_DIVIDE, 0, m, &cBinop_T5ZGK7tO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_O2AJPp2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y04mDXFR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_T5ZGK7tO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JHj2mBbu, HV_BINOP_MULTIPLY, 1, m, &cBinop_JHj2mBbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JHj2mBbu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8SzA8Rby_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TU1bPv4z_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_FhrupJlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NLGuDJpK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_k9RVqzgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZJyw3fsO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Q14wmfgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_xuRlLDm0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xuRlLDm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JHj2mBbu, HV_BINOP_MULTIPLY, 0, m, &cBinop_JHj2mBbu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0WoxYuV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_xb7TYZyT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xb7TYZyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T2JHbfge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FBZYySG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UlHSFMXt, HV_BINOP_MULTIPLY, 1, m, &cBinop_UlHSFMXt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PlXK60o2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qzeiS7pw, 1, m, &cVar_qzeiS7pw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LqXecq8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVsTaOx5, HV_BINOP_MULTIPLY, 1, m, &cBinop_IVsTaOx5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MIkJmXMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BBmmlHo4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BBmmlHo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6G4LN0w, HV_BINOP_MULTIPLY, 1, m, &cBinop_X6G4LN0w_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qzeiS7pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vyhCep29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XgDvdedK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rxIfq0v7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Q14wmfgT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yYhuF80Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FUF8sik2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0WoxYuV9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TU1bPv4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_k9RVqzgg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8SzA8Rby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FhrupJlp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_NLGuDJpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OG2oqp04_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ZJyw3fsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K4TOxKd5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_1NqGjpKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4nv2tkmO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_T2JHbfge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AxlUD2Cg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AxlUD2Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNHE70Or, HV_BINOP_MULTIPLY, 1, m, &cBinop_sNHE70Or_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sNHE70Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YbFpsOhV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YbFpsOhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1NqGjpKg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_vyhCep29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Jvi7GMf7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jvi7GMf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YayT8328_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_goQ8eRWA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k28O85CQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bExaq86S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_13f7rft3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FRfdqWA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UlHSFMXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E97Q04b9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IVsTaOx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3YFtrx3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_X6G4LN0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a79KRX3U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NT9L13Tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XgDvdedK, 0, m, &cVar_XgDvdedK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UJjvdhri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FUF8sik2, 1, m, &cVar_FUF8sik2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yYhuF80Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qzeiS7pw, 0, m, &cVar_qzeiS7pw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rxIfq0v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FUF8sik2, 0, m, &cVar_FUF8sik2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YayT8328_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X6G4LN0w, HV_BINOP_MULTIPLY, 0, m, &cBinop_X6G4LN0w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bExaq86S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_13f7rft3, HV_BINOP_MULTIPLY, 0, m, &cBinop_13f7rft3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_k28O85CQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UlHSFMXt, HV_BINOP_MULTIPLY, 0, m, &cBinop_UlHSFMXt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_goQ8eRWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVsTaOx5, HV_BINOP_MULTIPLY, 0, m, &cBinop_IVsTaOx5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tPHptSjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AYuQ1App, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pj2JWRaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8RhhWQvf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Dqy3P58E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LaHhP2Z2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_K7AjT4E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VhlTNYj1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FvfqblP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RWVVlYj2, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4SZY5IsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WNf6NE9X_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WNf6NE9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TcNYkLZO, HV_BINOP_DIVIDE, 1, m, &cBinop_TcNYkLZO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_viPYG5x0_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zhzUYxwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_ucBDQyRZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7wiTMsMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zhzUYxwV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ucBDQyRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TcNYkLZO, HV_BINOP_DIVIDE, 0, m, &cBinop_TcNYkLZO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_viPYG5x0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7wiTMsMz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TcNYkLZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F6IdN2zG, HV_BINOP_MULTIPLY, 1, m, &cBinop_F6IdN2zG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F6IdN2zG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZL4nLHBf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MjahsPeP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_TdB2bPqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qy79SR4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_28XpnaNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pqjQMfrM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IxOeGWIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mjPDBrMn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mjPDBrMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F6IdN2zG, HV_BINOP_MULTIPLY, 0, m, &cBinop_F6IdN2zG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sdpFE7tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_K3utqYGY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K3utqYGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9rSyzxLH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3Yr6Ecqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6btEgg6o, HV_BINOP_MULTIPLY, 1, m, &cBinop_6btEgg6o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qy0ZPVr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_n28v3n8c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n28v3n8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3Yr6Ecqi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aYAA5vQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MCZaho5r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MCZaho5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ye8L8WT1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ye8L8WT1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LS475JhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xW2IisyH, HV_BINOP_MULTIPLY, 1, m, &cBinop_xW2IisyH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7fNZnBr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GN9uJ87g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GN9uJ87g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LS475JhV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z7IRpRJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZcCAzttm, 1, m, &cVar_ZcCAzttm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R4RPfyqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Woug9vEv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Woug9vEv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HBPQdLTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CreakcFS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CreakcFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_00l6M1Z7, HV_BINOP_MULTIPLY, 1, m, &cBinop_00l6M1Z7_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZcCAzttm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dCksnJnx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_nKV3VcRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WBjFihkB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IxOeGWIq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_POeZYzQR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_BSQnhgwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_sdpFE7tV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MjahsPeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_28XpnaNW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZL4nLHBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TdB2bPqO_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_qy79SR4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k6dH5fXB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_pqjQMfrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nziBQju7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lg1q2Atw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_70uR3XUi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_9rSyzxLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JXlTT9NC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JXlTT9NC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rbIP2cb2, HV_BINOP_MULTIPLY, 1, m, &cBinop_rbIP2cb2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rbIP2cb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gSpoD3RP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gSpoD3RP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lg1q2Atw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_dCksnJnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mbGWkpzn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mbGWkpzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qNC1Gu5X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NsiFxEqd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VcAY08il_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4wz14TO3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gbNxWqoi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_McQEFQoe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6btEgg6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tPHptSjc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ye8L8WT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pj2JWRaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xW2IisyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dqy3P58E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Woug9vEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K7AjT4E2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_00l6M1Z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FvfqblP0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0n51guz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nKV3VcRg, 0, m, &cVar_nKV3VcRg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SnQwJL7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BSQnhgwv, 1, m, &cVar_BSQnhgwv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4wz14TO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xW2IisyH, HV_BINOP_MULTIPLY, 0, m, &cBinop_xW2IisyH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qNC1Gu5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_gbNxWqoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ye8L8WT1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ye8L8WT1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_McQEFQoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6btEgg6o, HV_BINOP_MULTIPLY, 0, m, &cBinop_6btEgg6o_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NsiFxEqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_00l6M1Z7, HV_BINOP_MULTIPLY, 0, m, &cBinop_00l6M1Z7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VcAY08il_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Woug9vEv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Woug9vEv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_POeZYzQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZcCAzttm, 0, m, &cVar_ZcCAzttm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WBjFihkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BSQnhgwv, 0, m, &cVar_BSQnhgwv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W2DppEM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0GbC0M3f, 1, m, &cIf_0GbC0M3f_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lZL7yS9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_81DZFLqG, m);
}

void Heavy_WSTD_DL3Y::cBinop_MXfRy7Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lZL7yS9P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YjBgR74c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0GbC0M3f, 0, m, &cIf_0GbC0M3f_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_0cAwuRYF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fZPDPrWm, 0, m, &cSlice_fZPDPrWm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Lrm3GO8N_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_fZPDPrWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7ZZi5M16_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7ZZi5M16_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zbeLt9MQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7ZZi5M16_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7ZZi5M16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2hFLgozJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ZH3mvOl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_05MEPmrh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_EIlR86Gh, 0, m, &cIf_EIlR86Gh_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_EIlR86Gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xt85VqYp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_zamV18li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pjRBfykV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_dHgV1eSL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Z6TIXpuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lDbciaYM, HV_BINOP_POW, 0, m, &cBinop_lDbciaYM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lDbciaYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AVsIU56O, 0, m, &cIf_AVsIU56O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KmIyxEo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1gzNgiq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vSFW4O3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JyQnPsYp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_u1K6eZbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zamV18li, 0, m, &cIf_zamV18li_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JyQnPsYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zamV18li, 1, m, &cIf_zamV18li_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dHgV1eSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_KmIyxEo0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pjRBfykV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AVsIU56O, 0, m, &cIf_AVsIU56O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1gzNgiq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lDbciaYM, HV_BINOP_POW, 1, m, &cBinop_lDbciaYM_sendMessage);
  cMsg_Z6TIXpuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_AVsIU56O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uhrbE4A6, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_05MEPmrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EIlR86Gh, 1, m, &cIf_EIlR86Gh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xt85VqYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfKCcfg4, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HfKCcfg4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3HBiquQO, HV_BINOP_EQ, 1, m, &cBinop_3HBiquQO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hhnXIP9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oUVg5SGS, HV_BINOP_ADD, 0, m, &cBinop_oUVg5SGS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oUVg5SGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vSFW4O3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u1K6eZbL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HfKCcfg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AVsIU56O, 1, m, &cIf_AVsIU56O_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3HBiquQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qe2j5jGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Qe2j5jGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uhrbE4A6, m);
}

void Heavy_WSTD_DL3Y::cCast_ftbVo9LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhnXIP9N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RxKbb7Cp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oUVg5SGS, HV_BINOP_ADD, 1, m, &cBinop_oUVg5SGS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfKCcfg4, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HfKCcfg4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3HBiquQO, HV_BINOP_EQ, 0, m, &cBinop_3HBiquQO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_043paqo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZH3mvOl6, 0, m, &cVar_ZH3mvOl6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_E3t3wJ69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_X3qjkNPa_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_vDfcGWmU, 0, m, &cIf_vDfcGWmU_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_vDfcGWmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_l5JJHDwh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_pbGl7MCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bKLXwABy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aFVK7SaK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_UFvaYSeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rFLGV6B, HV_BINOP_POW, 0, m, &cBinop_5rFLGV6B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5rFLGV6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5HEb7TP7, 0, m, &cIf_5HEb7TP7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RxC6aj9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dkEFJtuJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YyI2i5VP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pbGl7MCn, 0, m, &cIf_pbGl7MCn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WnuiEPhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_eMA2Cdtv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eMA2Cdtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pbGl7MCn, 1, m, &cIf_pbGl7MCn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aFVK7SaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_RxC6aj9r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bKLXwABy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5HEb7TP7, 0, m, &cIf_5HEb7TP7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dkEFJtuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5rFLGV6B, HV_BINOP_POW, 1, m, &cBinop_5rFLGV6B_sendMessage);
  cMsg_UFvaYSeD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_5HEb7TP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uxYREhSW_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4AREMp9b_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OIQUUnmg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_X3qjkNPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vDfcGWmU, 1, m, &cIf_vDfcGWmU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l5JJHDwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wB990Ou2, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wB990Ou2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UXqArws0, HV_BINOP_EQ, 1, m, &cBinop_UXqArws0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pz3eX5p2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ikgxi4wA, HV_BINOP_ADD, 0, m, &cBinop_Ikgxi4wA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ikgxi4wA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WnuiEPhI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YyI2i5VP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wB990Ou2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5HEb7TP7, 1, m, &cIf_5HEb7TP7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UXqArws0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q5zrDvve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Q5zrDvve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uxYREhSW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4AREMp9b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_OIQUUnmg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rR9FZq3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E3t3wJ69, 0, m, &cVar_E3t3wJ69_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1WMwaSVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pz3eX5p2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uTRcTZbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ikgxi4wA, HV_BINOP_ADD, 1, m, &cBinop_Ikgxi4wA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wB990Ou2, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wB990Ou2_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UXqArws0, HV_BINOP_EQ, 0, m, &cBinop_UXqArws0_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_hjdgief4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_v0RAXhtb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oEDfoxuM, 0, m, &cIf_oEDfoxuM_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_oEDfoxuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_dTpRlbXa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_h0uMxfPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_9D0LAcoj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JPFYAvgV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_lVQeqfJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IRGJoeaK, HV_BINOP_POW, 0, m, &cBinop_IRGJoeaK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IRGJoeaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MCQQImcD, 0, m, &cIf_MCQQImcD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kWh8yxo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_FUEaiFH1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bO1htNbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h0uMxfPX, 0, m, &cIf_h0uMxfPX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q6QAY0e8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9mDLjA0R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9mDLjA0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h0uMxfPX, 1, m, &cIf_h0uMxfPX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JPFYAvgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kWh8yxo6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9D0LAcoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MCQQImcD, 0, m, &cIf_MCQQImcD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FUEaiFH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IRGJoeaK, HV_BINOP_POW, 1, m, &cBinop_IRGJoeaK_sendMessage);
  cMsg_lVQeqfJQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_MCQQImcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_a6VLjl42, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_v0RAXhtb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oEDfoxuM, 1, m, &cIf_oEDfoxuM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dTpRlbXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JiPxEEHE, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JiPxEEHE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zkc9tq4c, HV_BINOP_EQ, 1, m, &cBinop_Zkc9tq4c_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2ND1gZ2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DxlUMPsn, HV_BINOP_ADD, 0, m, &cBinop_DxlUMPsn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DxlUMPsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q6QAY0e8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bO1htNbs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JiPxEEHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MCQQImcD, 1, m, &cIf_MCQQImcD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zkc9tq4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bvPds4eq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bvPds4eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_a6VLjl42, m);
}

void Heavy_WSTD_DL3Y::cCast_Fz2eFrWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hjdgief4, 0, m, &cVar_hjdgief4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gtzx4T6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ND1gZ2X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ITrykwMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DxlUMPsn, HV_BINOP_ADD, 1, m, &cBinop_DxlUMPsn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JiPxEEHE, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JiPxEEHE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zkc9tq4c, HV_BINOP_EQ, 0, m, &cBinop_Zkc9tq4c_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JNz3bG4k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_0C0Hnj1D, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_ezjVHXyI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mAj00J5m, 0, m, &cSlice_mAj00J5m_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dVry9PpT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_mAj00J5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_nfNi22KX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_nfNi22KX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_WYaVSJZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nfNi22KX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nfNi22KX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xHQ9pm7P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_dVry9PpT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OxxUFolh, 0, m, &cSlice_OxxUFolh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0cAwuRYF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_OxxUFolh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NDlZuCUf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NDlZuCUf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_k4l5hAQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NDlZuCUf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NDlZuCUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pH6TlMzr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Lrm3GO8N_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CzMo0pwU, 0, m, &cSlice_CzMo0pwU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_I9nDl6IB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CzMo0pwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yXuES1JS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yXuES1JS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wx5RiGQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yXuES1JS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_yXuES1JS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_edXfK5lj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_I9nDl6IB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HhoPMnNO, 0, m, &cSlice_HhoPMnNO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_HhoPMnNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rAQOFP3X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rAQOFP3X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_8oSTuWTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rAQOFP3X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rAQOFP3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FzXIJSMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_bfXweNaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_F0ko72bF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ctlcFjHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8IJ9l0fM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_iQ9tWbGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hNvBSVUl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1qg2nd2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OroIV9lu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_SINIJe14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ZdQz8YU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mn51Fk8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EEli8o0X_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EEli8o0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EyuDZMSu, HV_BINOP_DIVIDE, 1, m, &cBinop_EyuDZMSu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M3b73iIa_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3V0W2Tip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_s9Vjf7df_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oFJosHhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3V0W2Tip_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_s9Vjf7df_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EyuDZMSu, HV_BINOP_DIVIDE, 0, m, &cBinop_EyuDZMSu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M3b73iIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oFJosHhP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_EyuDZMSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q3tbVbQG, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q3tbVbQG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q3tbVbQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EbssocpE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H2BH73Jy_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_b0RxtpPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3UCK42ab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qxpOH0lH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FmDj51Lo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7NOEPY2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_t0QufQiG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t0QufQiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q3tbVbQG, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q3tbVbQG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JAPNBlD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_vMdmdhwV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vMdmdhwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xh6XoX4I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_P53x4Gar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jhjm27T8, 1, m, &cVar_Jhjm27T8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Jhjm27T8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o5JRbSlh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_49wN3vk4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kYsppk2, HV_BINOP_MULTIPLY, 1, m, &cBinop_1kYsppk2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bdY6HmkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_49wN3vk4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P7YqiTqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_22YN7We2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_22YN7We2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtOmAHdM, HV_BINOP_MULTIPLY, 1, m, &cBinop_QtOmAHdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RsiWE0OO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OiOA2bD6, HV_BINOP_MULTIPLY, 1, m, &cBinop_OiOA2bD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dEmrN7Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RsiWE0OO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WOo33RPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntVM66QB, HV_BINOP_MULTIPLY, 1, m, &cBinop_ntVM66QB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4EksZOnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_V3iK8iYP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V3iK8iYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvbSNGX8, HV_BINOP_MULTIPLY, 1, m, &cBinop_TvbSNGX8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MtWe9rhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CJKBP7oH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_7NOEPY2F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SDH0OvNw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_7xqJmUBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_JAPNBlD7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_H2BH73Jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_qxpOH0lH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EbssocpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_b0RxtpPI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_3UCK42ab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FNmEHAgC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_FmDj51Lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cRvsu54X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nkkqMMWZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SJgIOV4l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xh6XoX4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZWDGIdVB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZWDGIdVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VoPqS4fM, HV_BINOP_MULTIPLY, 1, m, &cBinop_VoPqS4fM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VoPqS4fM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jE324x5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jE324x5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nkkqMMWZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_o5JRbSlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WXdUKFx5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WXdUKFx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KtuVGLo3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_puUWSxRj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0pKSVX9j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z9Hus2S0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j5HXNjQJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0oOSzuL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1kYsppk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bfXweNaD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QtOmAHdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ctlcFjHi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OiOA2bD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iQ9tWbGl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ntVM66QB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1qg2nd2T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TvbSNGX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SINIJe14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_R431b3uV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MtWe9rhZ, 0, m, &cVar_MtWe9rhZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uzpsGxmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xqJmUBz, 1, m, &cVar_7xqJmUBz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_puUWSxRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvbSNGX8, HV_BINOP_MULTIPLY, 0, m, &cBinop_TvbSNGX8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KtuVGLo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_j5HXNjQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtOmAHdM, HV_BINOP_MULTIPLY, 0, m, &cBinop_QtOmAHdM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z9Hus2S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OiOA2bD6, HV_BINOP_MULTIPLY, 0, m, &cBinop_OiOA2bD6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0pKSVX9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ntVM66QB, HV_BINOP_MULTIPLY, 0, m, &cBinop_ntVM66QB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_B0oOSzuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1kYsppk2, HV_BINOP_MULTIPLY, 0, m, &cBinop_1kYsppk2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SDH0OvNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jhjm27T8, 0, m, &cVar_Jhjm27T8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CJKBP7oH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7xqJmUBz, 0, m, &cVar_7xqJmUBz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6OYFAfUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wDNEl99D, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_qM25ABfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9xMHmRlp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IEPWCCge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1n3h4wAe, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tgwUO1PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nkFvphH8, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_u0n6Hdcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kao2D8Pw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_kao2D8Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdro3a4j, HV_BINOP_DIVIDE, 1, m, &cBinop_pdro3a4j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UJYsYEFl_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_UuXcid9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_uGAHZS3W_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JK6zWs8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_UuXcid9B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uGAHZS3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pdro3a4j, HV_BINOP_DIVIDE, 0, m, &cBinop_pdro3a4j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UJYsYEFl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JK6zWs8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pdro3a4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f5ztFp6b, HV_BINOP_MULTIPLY, 1, m, &cBinop_f5ztFp6b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f5ztFp6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TfXIJdsE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZjZ6bpSC_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zQvyRJNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fAJZc6bs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_d9P2jdmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QT7ZRapJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PYyF5Oad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_gwtgpzPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gwtgpzPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f5ztFp6b, HV_BINOP_MULTIPLY, 0, m, &cBinop_f5ztFp6b_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NoR6yE9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_CgWqwD8e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CgWqwD8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0QoXp9yg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_O1RVdYs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FS5JGx72, HV_BINOP_MULTIPLY, 1, m, &cBinop_FS5JGx72_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7MlvmTjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aS658AFQ, 1, m, &cVar_aS658AFQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A4cuIrfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AP3N7oKL, HV_BINOP_MULTIPLY, 1, m, &cBinop_AP3N7oKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1gZhsmdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_95ZWWDqU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_95ZWWDqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hUrxS80k, HV_BINOP_MULTIPLY, 1, m, &cBinop_hUrxS80k_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_aS658AFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nns54dSg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_opwa3kVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZUj5JK5G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PYyF5Oad_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WOmjjEcb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MKq98he7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_NoR6yE9c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZjZ6bpSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_d9P2jdmx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TfXIJdsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_zQvyRJNd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_fAJZc6bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_O6rWZGEp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_QT7ZRapJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P27XG5Og_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_nOXPQvuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FveH3am0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0QoXp9yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dxGO9ttl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dxGO9ttl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CcHBnVmp, HV_BINOP_MULTIPLY, 1, m, &cBinop_CcHBnVmp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CcHBnVmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UPVpG41C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UPVpG41C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nOXPQvuD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_nns54dSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3e221XpJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3e221XpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nu8Yz6lu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t67yUMow_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JYICIrSO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ookaIV1Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MBZmrFIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6OYFAfUL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FS5JGx72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qM25ABfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AP3N7oKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IEPWCCge_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hUrxS80k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tgwUO1PY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZoghP7mU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_opwa3kVl, 0, m, &cVar_opwa3kVl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_u96ooQPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MKq98he7, 1, m, &cVar_MKq98he7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WOmjjEcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aS658AFQ, 0, m, &cVar_aS658AFQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZUj5JK5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MKq98he7, 0, m, &cVar_MKq98he7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JYICIrSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FS5JGx72, HV_BINOP_MULTIPLY, 0, m, &cBinop_FS5JGx72_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t67yUMow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AP3N7oKL, HV_BINOP_MULTIPLY, 0, m, &cBinop_AP3N7oKL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nu8Yz6lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hUrxS80k, HV_BINOP_MULTIPLY, 0, m, &cBinop_hUrxS80k_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ookaIV1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MBZmrFIS, HV_BINOP_MULTIPLY, 0, m, &cBinop_MBZmrFIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TAUFSnVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HgcRTfkJ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_AJcP0Xqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eyntfMig, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_f4PQPekR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M2nAZxzn, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Q8ZD4WQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yiFINTHQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YvHo05Su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fRKVhMgZ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_h3OCYCSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RhjnzDnu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RhjnzDnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIqlVN9K, HV_BINOP_DIVIDE, 1, m, &cBinop_NIqlVN9K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZeIQlCBk_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_le3sxr8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lbDEmkXD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lDfi87WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_le3sxr8s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lbDEmkXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIqlVN9K, HV_BINOP_DIVIDE, 0, m, &cBinop_NIqlVN9K_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZeIQlCBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lDfi87WU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NIqlVN9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yMgruy8d, HV_BINOP_MULTIPLY, 1, m, &cBinop_yMgruy8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yMgruy8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x9S6m8JH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ql1Yin0f_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_77aH2PMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yebPlBPp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_jDowNVmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uii59OtJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zMAhQXF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fQIHKlkT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fQIHKlkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yMgruy8d, HV_BINOP_MULTIPLY, 0, m, &cBinop_yMgruy8d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dpl455HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_bGVRIAUO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bGVRIAUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rSEcXMKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Kxwhm9vo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ocVOF5yF, HV_BINOP_MULTIPLY, 1, m, &cBinop_ocVOF5yF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VwmOgF5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mGmAXNbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mGmAXNbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Kxwhm9vo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jubqkVgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_anhU2rd3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_anhU2rd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LRoTbPss, HV_BINOP_MULTIPLY, 1, m, &cBinop_LRoTbPss_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1u68tLYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SSZ9tDod, HV_BINOP_MULTIPLY, 1, m, &cBinop_SSZ9tDod_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pIGbx2Cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8jLPDGfh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8jLPDGfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1u68tLYR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bixzS0Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_beSpTc54, 1, m, &cVar_beSpTc54_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FiIEFwzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8nYtrCCV, HV_BINOP_MULTIPLY, 1, m, &cBinop_8nYtrCCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vYuPEsdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oFStmFX4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oFStmFX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4qgaUIom, HV_BINOP_MULTIPLY, 1, m, &cBinop_4qgaUIom_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_beSpTc54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dUgNkcYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_eCbJiEmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qOwjNIoQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_zMAhQXF6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T9hjUQgK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Bao1AIbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dpl455HP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x9S6m8JH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_77aH2PMr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ql1Yin0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jDowNVmT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_yebPlBPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VV7w97yK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_uii59OtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PA49Fwzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EXle4GWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jl2F20Kz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_rSEcXMKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uKcCWJpu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uKcCWJpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nQx4FhwP, HV_BINOP_MULTIPLY, 1, m, &cBinop_nQx4FhwP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nQx4FhwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QiZIlSHS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QiZIlSHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EXle4GWM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_dUgNkcYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YT0Mc41n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YT0Mc41n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4TEoJF1L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qa9s3XhS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j5mCAydk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VEw7fliN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pC0Qd9XJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yS0iKtYR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ocVOF5yF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TAUFSnVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LRoTbPss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AJcP0Xqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SSZ9tDod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f4PQPekR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_8nYtrCCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q8ZD4WQS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4qgaUIom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YvHo05Su_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qOKNhfjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bao1AIbJ, 1, m, &cVar_Bao1AIbJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XClEluV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eCbJiEmn, 0, m, &cVar_eCbJiEmn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VEw7fliN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SSZ9tDod, HV_BINOP_MULTIPLY, 0, m, &cBinop_SSZ9tDod_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pC0Qd9XJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LRoTbPss, HV_BINOP_MULTIPLY, 0, m, &cBinop_LRoTbPss_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yS0iKtYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ocVOF5yF, HV_BINOP_MULTIPLY, 0, m, &cBinop_ocVOF5yF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Qa9s3XhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4qgaUIom, HV_BINOP_MULTIPLY, 0, m, &cBinop_4qgaUIom_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_j5mCAydk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8nYtrCCV, HV_BINOP_MULTIPLY, 0, m, &cBinop_8nYtrCCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4TEoJF1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_qOwjNIoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bao1AIbJ, 0, m, &cVar_Bao1AIbJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_T9hjUQgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_beSpTc54, 0, m, &cVar_beSpTc54_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uxYREhSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JNz3bG4k, 1, m, &cIf_JNz3bG4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zdjSXZQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0C0Hnj1D, m);
}

void Heavy_WSTD_DL3Y::cBinop_4AREMp9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zdjSXZQF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OIQUUnmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JNz3bG4k, 0, m, &cIf_JNz3bG4k_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_o2dGWIcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8xnGXJCa, HV_BINOP_DIVIDE, 0, m, &cBinop_8xnGXJCa_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PIVPAuaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7UeCkmp, HV_BINOP_DIVIDE, 1, m, &cBinop_x7UeCkmp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8xnGXJCa, HV_BINOP_DIVIDE, 1, m, &cBinop_8xnGXJCa_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_j66YTyLK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2poHrky5, HV_BINOP_DIVIDE, 0, m, &cBinop_2poHrky5_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_fAet9KDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2poHrky5, HV_BINOP_DIVIDE, 1, m, &cBinop_2poHrky5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DjsGvkl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PIVPAuaJ, 0, m, &cVar_PIVPAuaJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K4qAMt1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o2dGWIcQ, 0, m, &cVar_o2dGWIcQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_srovxlQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x7UeCkmp, HV_BINOP_DIVIDE, 0, m, &cBinop_x7UeCkmp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x7UeCkmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_j66YTyLK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8xnGXJCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_fAet9KDY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2poHrky5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3IiDKH8p_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ra6AMNZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_6M9yTgBr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n7MoQHh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_HwS77ilw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3IiDKH8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n7MoQHh1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HwS77ilw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ra6AMNZj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6M9yTgBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vIJAZNY2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_mFyE8y3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HEzCRziz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FxKZEaJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Szm8LVpm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_TABzL5ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8YDivj8C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_cSlNmWNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TFEQ9ShN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_7NfHwQ3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nH2mXYLX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MTW3ogoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c6zXn8Mi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_VdM4AORz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ldbhzzoh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_m0iZefOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZK9cMuc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_YRLRlpmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b2F8Fpt7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_SOxiB8GN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uztMDHvE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Mx6pdwcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6QqxDJsD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ecEMUUNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_80fpigAt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_HUd0PsyD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yrVZqAAS, 0, m, &cSlice_yrVZqAAS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_yrVZqAAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vD84zKMq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vD84zKMq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_B3gSS8LD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vD84zKMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vD84zKMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dtbg7JaI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_DpRyDrpP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XrBPz12y, 0, m, &cSlice_XrBPz12y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XMImImGA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_XrBPz12y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9ocTdQYn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9ocTdQYn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_D70C9Ciw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9ocTdQYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_9ocTdQYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wHvued1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_0YlFOUdA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1EssAy0r, 0, m, &cSlice_1EssAy0r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HUd0PsyD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_1EssAy0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SmVvrQlk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SmVvrQlk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_fc0jQ8vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SmVvrQlk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SmVvrQlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zphpTjim_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5spBtde2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_w3P3SnsG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w3P3SnsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ZBgltsIv_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_I4mJpvc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tc79mdxd_sendMessage(_c, 0, m);
  cMsg_pyEjVzql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_WHDPjMGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hOPuScjU_sendMessage(_c, 0, m);
  cMsg_Bm2NSWic_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZBgltsIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YEbCRhs0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YEbCRhs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4534BGvt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q3TD9el1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4534BGvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VW3hcPys_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Q3TD9el1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m9HnGn1f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VW3hcPys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5hWAkSth_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_m9HnGn1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dH6wx504_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dH6wx504_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hNcLpKHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5hWAkSth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_I4mJpvc1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hNcLpKHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_WHDPjMGz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QM9cy4Fo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hXc2Amm0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hXc2Amm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_2nQXzLav_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2nQXzLav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RdxoTz2S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RdxoTz2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vdbYxta3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L3sUAMWn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vdbYxta3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_V4Ogd8NY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L3sUAMWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6RABkCPH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_V4Ogd8NY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_n8GiYKwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6RABkCPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XxJwJEIo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XxJwJEIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_T1W4iGZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T1W4iGZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JygGAQyF_sendMessage(_c, 0, m);
  cMsg_953PEs2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_n8GiYKwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RMzdC9FV_sendMessage(_c, 0, m);
  cMsg_QSjfzPsA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jJKiK79I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7xR1Ky7G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7xR1Ky7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iVo29d2l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xsc5w3Lx_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_tzOVxEew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_mLEin66F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XasV9fkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IED1fKdn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_IED1fKdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3Rr8GpvG, HV_BINOP_DIVIDE, 1, m, &cBinop_3Rr8GpvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iVo29d2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Pujr1UHl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pujr1UHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FdrK9cjG, m);
}

void Heavy_WSTD_DL3Y::cMsg_LeREK5ZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5ejceAMA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5ejceAMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jJKiK79I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xsc5w3Lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gXg8aEzO, m);
}

void Heavy_WSTD_DL3Y::cBinop_mLEin66F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_iVcHp1P6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iVcHp1P6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3Rr8GpvG, HV_BINOP_DIVIDE, 0, m, &cBinop_3Rr8GpvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3Rr8GpvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LeREK5ZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_guiTjJqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0P8VNiOp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0P8VNiOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_L2HkKDv3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_le4rJPW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_W3nVsx9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ntHZXKcN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6H4vskO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Hscu47tV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Hscu47tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8w9Kw4V3, HV_BINOP_DIVIDE, 1, m, &cBinop_8w9Kw4V3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L2HkKDv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uhJeQvza_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uhJeQvza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ij7U779I, m);
}

void Heavy_WSTD_DL3Y::cMsg_ve5jTKp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_F4qlHsHm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F4qlHsHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_guiTjJqx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_le4rJPW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XbliOmNJ, m);
}

void Heavy_WSTD_DL3Y::cBinop_ntHZXKcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_bi8zpRUo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bi8zpRUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8w9Kw4V3, HV_BINOP_DIVIDE, 0, m, &cBinop_8w9Kw4V3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8w9Kw4V3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ve5jTKp7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_rezjnfAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pEfoD93Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_pEfoD93Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F9GDNL0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tfXmSodI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tfXmSodI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HcNCkQV8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pEfoD93Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_R6ynXJAK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f5YrLLoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pEfoD93Z, HV_BINOP_MULTIPLY, 1, m, &cBinop_pEfoD93Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HcNCkQV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_f5YrLLoX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R6ynXJAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6hpFNy3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6hpFNy3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RqcH9hCf_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GwQwkNMg, m);
}

void Heavy_WSTD_DL3Y::cBinop_RqcH9hCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qm81l0ZA, m);
}

void Heavy_WSTD_DL3Y::cVar_I4DDkla0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eQMLjUtX, HV_BINOP_MULTIPLY, 0, m, &cBinop_eQMLjUtX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_U1dWRQCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_B0ncLQb9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_B0ncLQb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iKbNBP0K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_eQMLjUtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cvorRmlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_luSrEzA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eQMLjUtX, HV_BINOP_MULTIPLY, 1, m, &cBinop_eQMLjUtX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iKbNBP0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_luSrEzA8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cvorRmlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_g8CWAWVu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g8CWAWVu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ijir4mXv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_XDmyN7U0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ijir4mXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ETdThg09, m);
}

void Heavy_WSTD_DL3Y::sEnv_3NM8vyFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SuFfxCz0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gXOXqFMI_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_OwzaKlXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WSS8AJY8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LSk36zXb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_yRl5K9H3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_axNf8wiW, HV_BINOP_POW, 0, m, &cBinop_axNf8wiW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_axNf8wiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YuVoz8q1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WDnaj3RM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_RLn8wHtj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gXOXqFMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OwzaKlXn, 0, m, &cIf_OwzaKlXn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SuFfxCz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iw8Yv9O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iw8Yv9O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OwzaKlXn, 1, m, &cIf_OwzaKlXn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LSk36zXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WDnaj3RM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WSS8AJY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_YuVoz8q1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RLn8wHtj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_axNf8wiW, HV_BINOP_POW, 1, m, &cBinop_axNf8wiW_sendMessage);
  cMsg_yRl5K9H3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_8hOp9xqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GH6HKora, HV_BINOP_MULTIPLY, 0, m, &cBinop_GH6HKora_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_88cCTdue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7beePKSW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7beePKSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wb2eNGl4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GH6HKora_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_M1kQ8oQE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vkwbiOb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GH6HKora, HV_BINOP_MULTIPLY, 1, m, &cBinop_GH6HKora_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wb2eNGl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vkwbiOb7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M1kQ8oQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_g7QdM2ZE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g7QdM2ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nFKPjkFK_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_c5GKq47s, m);
}

void Heavy_WSTD_DL3Y::cBinop_nFKPjkFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MrllREA8, m);
}

void Heavy_WSTD_DL3Y::cMsg_YuVoz8q1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WUaokCqk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WUaokCqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1fhR3Fi8, m);
}

void Heavy_WSTD_DL3Y::sEnv_3Ur5xe5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KbSkt4Q4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NfNeSQjq_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_z6UZCqPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_VMg3CGx1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WS91jxYu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Yob6AEtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5kAYNnbM, HV_BINOP_POW, 0, m, &cBinop_5kAYNnbM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5kAYNnbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mnf4BOcr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Mnsl2RJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IsKyNQLQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NfNeSQjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z6UZCqPY, 0, m, &cIf_z6UZCqPY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KbSkt4Q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_POco9UUK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_POco9UUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z6UZCqPY, 1, m, &cIf_z6UZCqPY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WS91jxYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Mnsl2RJT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VMg3CGx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Mnf4BOcr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IsKyNQLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5kAYNnbM, HV_BINOP_POW, 1, m, &cBinop_5kAYNnbM_sendMessage);
  cMsg_Yob6AEtC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ddNAi7O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WguIvRDd, HV_BINOP_MULTIPLY, 0, m, &cBinop_WguIvRDd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ImbtyxW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0pUfJuim_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0pUfJuim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KbEhklor_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WguIvRDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Deu8J7gg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fhRexl1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WguIvRDd, HV_BINOP_MULTIPLY, 1, m, &cBinop_WguIvRDd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KbEhklor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_fhRexl1F_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Deu8J7gg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IY4QqX1V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IY4QqX1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_keFclJSO_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Kc4xE38x, m);
}

void Heavy_WSTD_DL3Y::cBinop_keFclJSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_64sZ3ziu, m);
}

void Heavy_WSTD_DL3Y::cMsg_Mnf4BOcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_U48ffF4P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_U48ffF4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2vs4YYz0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XMImImGA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_c7uD0Sx5, 0, m, &cSlice_c7uD0Sx5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0YlFOUdA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_c7uD0Sx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DG1wj3bx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DG1wj3bx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_jW2QKe1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DG1wj3bx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_DG1wj3bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xyn50kgF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_irsuZkGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2d0GfTNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_2d0GfTNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7Oz5H9P5_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_NSlmspRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NSlmspRs, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ifT5vfuB, 0, m, &cDelay_ifT5vfuB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NSlmspRs, 0, m, &cDelay_NSlmspRs_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VrlnEtB7, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_ifT5vfuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ifT5vfuB, m);
  cMsg_WXyldLvQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_lGmm2foH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_SEcpudYG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Sc368YsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L4oMCcxo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_8HPMpveJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6tCnnePl_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NSlmspRs, 2, m, &cDelay_NSlmspRs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yw3jtdNW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_L4oMCcxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8HPMpveJ, 0, m, &hTable_8HPMpveJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Oz5H9P5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Sc368YsB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WXyldLvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8HPMpveJ, 0, m, &hTable_8HPMpveJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Yw3jtdNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NSlmspRs, 0, m, &cDelay_NSlmspRs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6tCnnePl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ifT5vfuB, 2, m, &cDelay_ifT5vfuB_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SEcpudYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_VrlnEtB7, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_F4GtTbIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QsLjjppo, HV_BINOP_SUBTRACT, 0, m, &cBinop_QsLjjppo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_t6EGukW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vlJfOtVa_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_vlJfOtVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3NIGPRwd_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_iS1RJB7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wkoivJcO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_JAB625bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JAB625bp, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1MsYHVG, 0, m, &cDelay_O1MsYHVG_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cDDUNJrW, 0, m, &sTabread_cDDUNJrW_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_O1MsYHVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_O1MsYHVG, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cDDUNJrW, 0, m, &sTabread_cDDUNJrW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1MsYHVG, 0, m, &cDelay_O1MsYHVG_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_cDDUNJrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_THrpNLPk, HV_BINOP_SUBTRACT, 0, m, &cBinop_THrpNLPk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_pbsmgdOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x35Tjxlx, HV_BINOP_MAX, 0, m, &cBinop_x35Tjxlx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3NIGPRwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pbsmgdOr, HV_BINOP_MULTIPLY, 0, m, &cBinop_pbsmgdOr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QsLjjppo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N3gnQahf_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cDDUNJrW, 0, m, &sTabread_cDDUNJrW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VDdQhgsH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KjSqqlyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_THrpNLPk, HV_BINOP_SUBTRACT, 1, m, &cBinop_THrpNLPk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1MsYHVG, 2, m, &cDelay_O1MsYHVG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wkoivJcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KjSqqlyV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_N3gnQahf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JAB625bp, 0, m, &cDelay_JAB625bp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_O1MsYHVG, 0, m, &cDelay_O1MsYHVG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hoxXKhgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_x35Tjxlx, HV_BINOP_MAX, 1, m, &cBinop_x35Tjxlx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x35Tjxlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QsLjjppo, HV_BINOP_SUBTRACT, 1, m, &cBinop_QsLjjppo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VDdQhgsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JAB625bp, 0, m, &cDelay_JAB625bp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SfvHz1bH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JAB625bp, 2, m, &cDelay_JAB625bp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_THrpNLPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SfvHz1bH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4sFRyR5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iS1RJB7L, 0, m, &cVar_iS1RJB7L_sendMessage);
  cMsg_t6EGukW3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_F4GtTbIr, 0, m, &cTabhead_F4GtTbIr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XWViuADO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_chCEuP9T_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_chCEuP9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_AHkcxLdO_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_gKvpVmBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gKvpVmBK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ohby44aQ, 0, m, &cDelay_ohby44aQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gKvpVmBK, 0, m, &cDelay_gKvpVmBK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UipxQ9Q2, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_ohby44aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ohby44aQ, m);
  cMsg_nUdcOmYM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KW8IdS8d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_5NNI2THj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_z0FtDNHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ECsfdLBQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_XbXIcMtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i0qyPQWg_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gKvpVmBK, 2, m, &cDelay_gKvpVmBK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F1Mg0LSE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ECsfdLBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_XbXIcMtB, 0, m, &hTable_XbXIcMtB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AHkcxLdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_z0FtDNHs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nUdcOmYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_XbXIcMtB, 0, m, &hTable_XbXIcMtB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_F1Mg0LSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gKvpVmBK, 0, m, &cDelay_gKvpVmBK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_i0qyPQWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ohby44aQ, 2, m, &cDelay_ohby44aQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5NNI2THj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_UipxQ9Q2, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_kauJ8r1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GM4SvBTy, HV_BINOP_SUBTRACT, 0, m, &cBinop_GM4SvBTy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wen2Bi8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3GW4ufPq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_3GW4ufPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_WW9i60et_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Uwarmot4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ww1vIQtz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_J4paqwOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_J4paqwOg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4BE0u8b, 0, m, &cDelay_N4BE0u8b_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XSVARinO, 0, m, &sTabread_XSVARinO_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_N4BE0u8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N4BE0u8b, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XSVARinO, 0, m, &sTabread_XSVARinO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4BE0u8b, 0, m, &cDelay_N4BE0u8b_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_XSVARinO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_8mP47vnN, HV_BINOP_SUBTRACT, 0, m, &cBinop_8mP47vnN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_izPin5kW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEPeO9b8, HV_BINOP_MAX, 0, m, &cBinop_UEPeO9b8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WW9i60et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_izPin5kW, HV_BINOP_MULTIPLY, 0, m, &cBinop_izPin5kW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GM4SvBTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hZBSpdkm_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_XSVARinO, 0, m, &sTabread_XSVARinO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jyt5HumP_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6DFMG0Mw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8mP47vnN, HV_BINOP_SUBTRACT, 1, m, &cBinop_8mP47vnN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4BE0u8b, 2, m, &cDelay_N4BE0u8b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Ww1vIQtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6DFMG0Mw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hZBSpdkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_J4paqwOg, 0, m, &cDelay_J4paqwOg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4BE0u8b, 0, m, &cDelay_N4BE0u8b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jkkZyCTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEPeO9b8, HV_BINOP_MAX, 1, m, &cBinop_UEPeO9b8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UEPeO9b8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GM4SvBTy, HV_BINOP_SUBTRACT, 1, m, &cBinop_GM4SvBTy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Jyt5HumP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_J4paqwOg, 0, m, &cDelay_J4paqwOg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UiwtIEHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_J4paqwOg, 2, m, &cDelay_J4paqwOg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8mP47vnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UiwtIEHX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TVYQW88U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uwarmot4, 0, m, &cVar_Uwarmot4_sendMessage);
  cMsg_Wen2Bi8G_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kauJ8r1J, 0, m, &cTabhead_kauJ8r1J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tc79mdxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ld81jzZc, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hOPuScjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qca1B6tO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Bm2NSWic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SJhBnlC3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_pyEjVzql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T967aA45, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_QSjfzPsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yohbZYcF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_JygGAQyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dcvx6aMT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RMzdC9FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DKrV1FLI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_953PEs2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HSonlW4E, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_t9iF4TSB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3BdVXcZj, 0, m, &cSlice_3BdVXcZj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_3BdVXcZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6KHgqRGv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6KHgqRGv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_274n9S7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6KHgqRGv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_6KHgqRGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W0JlXdxJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XsExLYiq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hUW1BZnF, 0, m, &cSlice_hUW1BZnF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EW0B86An_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_hUW1BZnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xrTTqNsh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xrTTqNsh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_iWxVhMIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xrTTqNsh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xrTTqNsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hLfnkFAC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_pVW0l1OC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IwWnix50, 0, m, &cSlice_IwWnix50_sendMessage);
      break;
    }
    default: {
      cSwitchcase_t9iF4TSB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_IwWnix50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hZC9riID_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hZC9riID_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_DiQ3Qca1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hZC9riID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hZC9riID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OK3WIORE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Zgkot3rz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yNvHuJ7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yNvHuJ7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_XrD3NKgU_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_JNoPEEjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vMXbwb9M_sendMessage(_c, 0, m);
  cMsg_lpWh3FvH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_WDEm4i7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XRGPWbkC_sendMessage(_c, 0, m);
  cMsg_80qZ9pyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XrD3NKgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wxqY7KBz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wxqY7KBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YklQ89gY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dpskQDEN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dpskQDEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vX2lABoP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YklQ89gY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uj1E8smA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uj1E8smA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RKgd6bKP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vX2lABoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6MiCKhzO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6MiCKhzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FaCsfhfC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RKgd6bKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_JNoPEEjN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FaCsfhfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_WDEm4i7D_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tr50wPsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Zd1hD1mL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Zd1hD1mL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_SFZiwXNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SFZiwXNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Giy22CdO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Giy22CdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qDgwcJJd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pcQiX9DZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qDgwcJJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YrghuAjF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pcQiX9DZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6hMsvoqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YrghuAjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OiJGLM5A_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6hMsvoqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_f8uPBc67_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f8uPBc67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HBvK8kdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HBvK8kdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fp7cJoPR_sendMessage(_c, 0, m);
  cMsg_rl3G6FOg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OiJGLM5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_My26qoy7_sendMessage(_c, 0, m);
  cMsg_UMEaPOm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_t04G09Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4fuCQ27Q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4fuCQ27Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_GIpTMyVv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_THyw18zY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gSD8t8XO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_kmr07cqM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eeAc8Xkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KpEatQsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KpEatQsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkT2iyBP, HV_BINOP_DIVIDE, 1, m, &cBinop_nkT2iyBP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GIpTMyVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ueB2ZHG3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ueB2ZHG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6KXxTGnk, m);
}

void Heavy_WSTD_DL3Y::cMsg_9hxlHd0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TXIz2jKe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TXIz2jKe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_t04G09Jt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_THyw18zY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Hl2VWnF0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kmr07cqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_HLSJloqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HLSJloqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkT2iyBP, HV_BINOP_DIVIDE, 0, m, &cBinop_nkT2iyBP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nkT2iyBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9hxlHd0J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tSHY1Iyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rm4N9Xbv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rm4N9Xbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xoUoojQY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_k2uimZ14_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_fpxTmhQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_dWm9SGeR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Vdjyg4Bd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_f5SH02LW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_f5SH02LW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t5XTIhOi, HV_BINOP_DIVIDE, 1, m, &cBinop_t5XTIhOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xoUoojQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QhuJtaG6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QhuJtaG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pr06Jslp, m);
}

void Heavy_WSTD_DL3Y::cMsg_aLaUeewa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iPcsRnu1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iPcsRnu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tSHY1Iyt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k2uimZ14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KhRYLDTl, m);
}

void Heavy_WSTD_DL3Y::cBinop_dWm9SGeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_5GOdj364_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5GOdj364_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t5XTIhOi, HV_BINOP_DIVIDE, 0, m, &cBinop_t5XTIhOi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t5XTIhOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLaUeewa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_WunJiGUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_64pzUSgs, HV_BINOP_MULTIPLY, 0, m, &cBinop_64pzUSgs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YTnto1OY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YDRbzggU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YDRbzggU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bQCHlXGG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_64pzUSgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZnOrPWa4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ojxOrscP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_64pzUSgs, HV_BINOP_MULTIPLY, 1, m, &cBinop_64pzUSgs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bQCHlXGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ojxOrscP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZnOrPWa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_PBkGsAOw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PBkGsAOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_bLXL5JSn_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gYAC76SU, m);
}

void Heavy_WSTD_DL3Y::cBinop_bLXL5JSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_viTTaNIf, m);
}

void Heavy_WSTD_DL3Y::cVar_PBay6eda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lgcZB3lG, HV_BINOP_MULTIPLY, 0, m, &cBinop_lgcZB3lG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Dq1Xq0py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2J9UVmJJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_2J9UVmJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PXTjcNLs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lgcZB3lG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_SrmvmvJI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZMEZxhCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lgcZB3lG, HV_BINOP_MULTIPLY, 1, m, &cBinop_lgcZB3lG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PXTjcNLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZMEZxhCf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SrmvmvJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_BXlaVEnx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BXlaVEnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_iFjUXocs_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Kv7rY4Hf, m);
}

void Heavy_WSTD_DL3Y::cBinop_iFjUXocs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DT1rW6L0, m);
}

void Heavy_WSTD_DL3Y::sEnv_exOBYnSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WOiGuO8f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VzSp1lYG_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_dxmBtjJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HwEuyG0o_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_kNIkVoxY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_3xqUmmXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xd5XAx3o, HV_BINOP_POW, 0, m, &cBinop_Xd5XAx3o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xd5XAx3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GzQlc4LA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sfVZreE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_VxsFqjV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VzSp1lYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dxmBtjJr, 0, m, &cIf_dxmBtjJr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WOiGuO8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ifiKGQDa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ifiKGQDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dxmBtjJr, 1, m, &cIf_dxmBtjJr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kNIkVoxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sfVZreE6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HwEuyG0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_GzQlc4LA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VxsFqjV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xd5XAx3o, HV_BINOP_POW, 1, m, &cBinop_Xd5XAx3o_sendMessage);
  cMsg_3xqUmmXA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DnEgOjpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LOYJCaHa, HV_BINOP_MULTIPLY, 0, m, &cBinop_LOYJCaHa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EOmnoCVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CiUnymRU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CiUnymRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mtn81PsQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_LOYJCaHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9Fh4Unya_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FPNbE879_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LOYJCaHa, HV_BINOP_MULTIPLY, 1, m, &cBinop_LOYJCaHa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Mtn81PsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FPNbE879_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9Fh4Unya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_t44igBxe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t44igBxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_705bqMXc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_yHhqifyN, m);
}

void Heavy_WSTD_DL3Y::cBinop_705bqMXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FbS1wYDV, m);
}

void Heavy_WSTD_DL3Y::cMsg_GzQlc4LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_f5gXLy2Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f5gXLy2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_NeLd2ecQ, m);
}

void Heavy_WSTD_DL3Y::sEnv_ZZdJf1AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JAmy63yG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GnoLNWBX_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_2quMAYGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_OVd77lFm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3z4tX2CC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_qoH4LXma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vse6Vs1T, HV_BINOP_POW, 0, m, &cBinop_vse6Vs1T_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vse6Vs1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XQ2MlHvv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2w5ssIFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_PQ46S11e_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JAmy63yG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GH1wr7z4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GnoLNWBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2quMAYGF, 0, m, &cIf_2quMAYGF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GH1wr7z4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2quMAYGF, 1, m, &cIf_2quMAYGF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3z4tX2CC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_2w5ssIFh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OVd77lFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_XQ2MlHvv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PQ46S11e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vse6Vs1T, HV_BINOP_POW, 1, m, &cBinop_vse6Vs1T_sendMessage);
  cMsg_qoH4LXma_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_17aBEsbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m7BwMjLo, HV_BINOP_MULTIPLY, 0, m, &cBinop_m7BwMjLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VMSHKzSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0tVBavA7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_0tVBavA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZEancEBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_m7BwMjLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ybAhcr60_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_56Xsh8jX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m7BwMjLo, HV_BINOP_MULTIPLY, 1, m, &cBinop_m7BwMjLo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZEancEBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_56Xsh8jX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ybAhcr60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zBAeZMdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zBAeZMdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tdkcG1C2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0IHZNvvW, m);
}

void Heavy_WSTD_DL3Y::cBinop_tdkcG1C2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_omidDxOV, m);
}

void Heavy_WSTD_DL3Y::cMsg_XQ2MlHvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GrCi4wM4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GrCi4wM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7cr0nyxy, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EW0B86An_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_88s5lHee, 0, m, &cSlice_88s5lHee_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pVW0l1OC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_88s5lHee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_j2RRBmlG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_j2RRBmlG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zFlf2zdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j2RRBmlG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_j2RRBmlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KGh0Llek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_G25uFVtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z7JzgPEK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Z7JzgPEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jVqQ0VRd_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_LR9aJ9O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LR9aJ9O7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y6kQldqa, 0, m, &cDelay_Y6kQldqa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LR9aJ9O7, 0, m, &cDelay_LR9aJ9O7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_72VoPxid, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Y6kQldqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y6kQldqa, m);
  cMsg_HHVQPG3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iRe4MkTU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_S8H2P8is_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_LOjHKHh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1kmjstBz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_FCBqCvS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DOXbvLZs_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LR9aJ9O7, 2, m, &cDelay_LR9aJ9O7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OgG0sKPY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1kmjstBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_FCBqCvS2, 0, m, &hTable_FCBqCvS2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jVqQ0VRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_LOjHKHh5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HHVQPG3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_FCBqCvS2, 0, m, &hTable_FCBqCvS2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OgG0sKPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LR9aJ9O7, 0, m, &cDelay_LR9aJ9O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DOXbvLZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y6kQldqa, 2, m, &cDelay_Y6kQldqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S8H2P8is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_72VoPxid, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_dneQWYhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iw0Rxw0a, HV_BINOP_SUBTRACT, 0, m, &cBinop_Iw0Rxw0a_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sYQJUFEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8uW1TYV7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_8uW1TYV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_19Hc4mmO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zgdgXT1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WfSpWNF6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_mW6fLdjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mW6fLdjc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4fAz1CY, 0, m, &cDelay_C4fAz1CY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CX3DdD67, 0, m, &sTabread_CX3DdD67_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_C4fAz1CY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C4fAz1CY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CX3DdD67, 0, m, &sTabread_CX3DdD67_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4fAz1CY, 0, m, &cDelay_C4fAz1CY_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_CX3DdD67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_P1P4Y6MT, HV_BINOP_SUBTRACT, 0, m, &cBinop_P1P4Y6MT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_rdF1B6xJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y5m1XVPs, HV_BINOP_MAX, 0, m, &cBinop_y5m1XVPs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_19Hc4mmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rdF1B6xJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_rdF1B6xJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Iw0Rxw0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QSOUfHVf_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_CX3DdD67, 0, m, &sTabread_CX3DdD67_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ddSjP2u_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GAXcMaKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P1P4Y6MT, HV_BINOP_SUBTRACT, 1, m, &cBinop_P1P4Y6MT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4fAz1CY, 2, m, &cDelay_C4fAz1CY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WfSpWNF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GAXcMaKN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QSOUfHVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mW6fLdjc, 0, m, &cDelay_mW6fLdjc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C4fAz1CY, 0, m, &cDelay_C4fAz1CY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gMjPKmUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_y5m1XVPs, HV_BINOP_MAX, 1, m, &cBinop_y5m1XVPs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y5m1XVPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iw0Rxw0a, HV_BINOP_SUBTRACT, 1, m, &cBinop_Iw0Rxw0a_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0ddSjP2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mW6fLdjc, 0, m, &cDelay_mW6fLdjc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_017qchI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mW6fLdjc, 2, m, &cDelay_mW6fLdjc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P1P4Y6MT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_017qchI9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nkxI985e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zgdgXT1x, 0, m, &cVar_zgdgXT1x_sendMessage);
  cMsg_sYQJUFEF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_dneQWYhC, 0, m, &cTabhead_dneQWYhC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HAkdRTZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PK4Ix1bI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_PK4Ix1bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FWA1lG9y_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_cp8FYcgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cp8FYcgK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kwhCUjqI, 0, m, &cDelay_kwhCUjqI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cp8FYcgK, 0, m, &cDelay_cp8FYcgK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tcC5eXT9, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_kwhCUjqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kwhCUjqI, m);
  cMsg_D1b2IkPz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_CFJ7THWV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_59u2S07V_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_8FCTmzHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B2Rv7BF6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_FwVkR2wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wSXPtycC_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cp8FYcgK, 2, m, &cDelay_cp8FYcgK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OHYTMZB5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_B2Rv7BF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_FwVkR2wI, 0, m, &hTable_FwVkR2wI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FWA1lG9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_8FCTmzHg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D1b2IkPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_FwVkR2wI, 0, m, &hTable_FwVkR2wI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OHYTMZB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cp8FYcgK, 0, m, &cDelay_cp8FYcgK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wSXPtycC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_kwhCUjqI, 2, m, &cDelay_kwhCUjqI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_59u2S07V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_tcC5eXT9, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_OyhPKcdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3c73CuIE, HV_BINOP_SUBTRACT, 0, m, &cBinop_3c73CuIE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JR2KJ18h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YaMgW314_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_YaMgW314_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_C87mlEuk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xpGSKRxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RILqBeq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_9cbeGmXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9cbeGmXl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2GBqii6, 0, m, &cDelay_z2GBqii6_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_I5GDdxiY, 0, m, &sTabread_I5GDdxiY_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_z2GBqii6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z2GBqii6, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_I5GDdxiY, 0, m, &sTabread_I5GDdxiY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2GBqii6, 0, m, &cDelay_z2GBqii6_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_I5GDdxiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_d9T5yXEz, HV_BINOP_SUBTRACT, 0, m, &cBinop_d9T5yXEz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_beuJeVO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQivYBT7, HV_BINOP_MAX, 0, m, &cBinop_vQivYBT7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C87mlEuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_beuJeVO9, HV_BINOP_MULTIPLY, 0, m, &cBinop_beuJeVO9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3c73CuIE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LmUeM5Uv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_I5GDdxiY, 0, m, &sTabread_I5GDdxiY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gqm0oSEF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lAsfmUh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d9T5yXEz, HV_BINOP_SUBTRACT, 1, m, &cBinop_d9T5yXEz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2GBqii6, 2, m, &cDelay_z2GBqii6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RILqBeq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lAsfmUh0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LmUeM5Uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9cbeGmXl, 0, m, &cDelay_9cbeGmXl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z2GBqii6, 0, m, &cDelay_z2GBqii6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Sn9oUhLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQivYBT7, HV_BINOP_MAX, 1, m, &cBinop_vQivYBT7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vQivYBT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3c73CuIE, HV_BINOP_SUBTRACT, 1, m, &cBinop_3c73CuIE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Gqm0oSEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9cbeGmXl, 0, m, &cDelay_9cbeGmXl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4wGPVGtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9cbeGmXl, 2, m, &cDelay_9cbeGmXl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d9T5yXEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4wGPVGtc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sDC5rdeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xpGSKRxr, 0, m, &cVar_xpGSKRxr_sendMessage);
  cMsg_JR2KJ18h_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OyhPKcdz, 0, m, &cTabhead_OyhPKcdz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vMXbwb9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1iWzq5fB, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_XRGPWbkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NqvJu6LU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_80qZ9pyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_702bVxoo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lpWh3FvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WRbfQt8y, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UMEaPOm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lyaalCbg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Fp7cJoPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KTRiXuvp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_My26qoy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GRLPEUIu, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rl3G6FOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KK3vuWZW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_V9AUtd9E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_087D8NX3, 0, m, &cSlice_087D8NX3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_087D8NX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sC0qUDHg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sC0qUDHg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_dleIlgbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sC0qUDHg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_sC0qUDHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DktlemJo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_7QCf5aRj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6mQIDiky, 0, m, &cSlice_6mQIDiky_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vlQ0ZGHH_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_6mQIDiky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Y3PlpQkF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Y3PlpQkF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_bJrmdpAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y3PlpQkF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Y3PlpQkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kCZB0hcO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LanJ5H3n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IfCluGMB, 0, m, &cSlice_IfCluGMB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_V9AUtd9E_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_IfCluGMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OYU1g9Hi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OYU1g9Hi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_o7ARrhsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OYU1g9Hi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_OYU1g9Hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QgiHht3N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kf2LvhES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_I9BZjjTD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I9BZjjTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_4w0yIL1h_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_70YEIEsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PxxAXlB2_sendMessage(_c, 0, m);
  cMsg_ThvXzsan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qltpIsLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZXiq1Zbq_sendMessage(_c, 0, m);
  cMsg_4aSs5GKT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4w0yIL1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PopYegrP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PopYegrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NPYzxuvA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HkiBD49M_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HkiBD49M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4F75MP5k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NPYzxuvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uqnyv2JB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uqnyv2JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sin8uOBK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4F75MP5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Oz88elzw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Oz88elzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kwMz5eib_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sin8uOBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_70YEIEsQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kwMz5eib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qltpIsLA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a7bSQaAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_J20LLKPJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J20LLKPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_5XgevnyW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5XgevnyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yppWlFRP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yppWlFRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6UkiljwL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ojo991cD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6UkiljwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oQU2qLkQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ojo991cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y9pKwHVF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oQU2qLkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qSRwW8YW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Y9pKwHVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VB5VnSdp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VB5VnSdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zHOXDL6c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zHOXDL6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s7vBg2WS_sendMessage(_c, 0, m);
  cMsg_8xAXwhpL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qSRwW8YW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cnrgeD4q_sendMessage(_c, 0, m);
  cMsg_n47MCoww_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_udZQpt3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Vo3vMb2G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vo3vMb2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UM9LSOmf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HVghxgEP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Do1AHElv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_oPkt9Oo7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_g5V4DEXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bRjxLPj5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bRjxLPj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9nsf6f2, HV_BINOP_DIVIDE, 1, m, &cBinop_c9nsf6f2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UM9LSOmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hY9CIFpX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hY9CIFpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FqBwC6vH, m);
}

void Heavy_WSTD_DL3Y::cMsg_kw4bNrlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ras8vAQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ras8vAQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_udZQpt3R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HVghxgEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JGXmGjsr, m);
}

void Heavy_WSTD_DL3Y::cBinop_oPkt9Oo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_DJ0iOk9k_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DJ0iOk9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c9nsf6f2, HV_BINOP_DIVIDE, 0, m, &cBinop_c9nsf6f2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c9nsf6f2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kw4bNrlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_d0Z3KN6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Vtjm5fZ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vtjm5fZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9ogFUU5T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EyTNv6xk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1R6WlJjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_3f2XXSWA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CyyW3mhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mbk66D3a_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_mbk66D3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_El6p2kqL, HV_BINOP_DIVIDE, 1, m, &cBinop_El6p2kqL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ogFUU5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6Wf6SZcJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Wf6SZcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_skYCdhEk, m);
}

void Heavy_WSTD_DL3Y::cMsg_FlC4jmYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BujjYFrV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BujjYFrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_d0Z3KN6H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EyTNv6xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HHgyGoGd, m);
}

void Heavy_WSTD_DL3Y::cBinop_3f2XXSWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_6xIzlwYS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6xIzlwYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_El6p2kqL, HV_BINOP_DIVIDE, 0, m, &cBinop_El6p2kqL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_El6p2kqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FlC4jmYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_lAJr7jSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XblSYjgc, HV_BINOP_MULTIPLY, 0, m, &cBinop_XblSYjgc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HYf4tnuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZBjp7ser_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ZBjp7ser_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QYg9VV2c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XblSYjgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CXhB2oZX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QXUAxY1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XblSYjgc, HV_BINOP_MULTIPLY, 1, m, &cBinop_XblSYjgc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QYg9VV2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QXUAxY1z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CXhB2oZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tJrSwqwu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tJrSwqwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wITD1o9z_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Fa84xRqF, m);
}

void Heavy_WSTD_DL3Y::cBinop_wITD1o9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DzTf67KN, m);
}

void Heavy_WSTD_DL3Y::cVar_MJPhbEM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7auaTMNu, HV_BINOP_MULTIPLY, 0, m, &cBinop_7auaTMNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CbmpL6it_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_h8rY0fp4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_h8rY0fp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcgrC9TE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7auaTMNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RhfXgqoz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g0pEV6EB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7auaTMNu, HV_BINOP_MULTIPLY, 1, m, &cBinop_7auaTMNu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NcgrC9TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_g0pEV6EB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RhfXgqoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Z5TroyOF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z5TroyOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZuEjVutW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EAbArrXN, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZuEjVutW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_YqLtNHxp, m);
}

void Heavy_WSTD_DL3Y::sEnv_3J942x7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5LinvQxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lko0rXZl_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_hbYwnGrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_tlvNre0F_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_PJhIKD80_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_41JqGMft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EfAe3rAa, HV_BINOP_POW, 0, m, &cBinop_EfAe3rAa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EfAe3rAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f0feUt3v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_loRQ6feF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_JMCy3ciz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Lko0rXZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hbYwnGrk, 0, m, &cIf_hbYwnGrk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5LinvQxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_C6913a8W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C6913a8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hbYwnGrk, 1, m, &cIf_hbYwnGrk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PJhIKD80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_loRQ6feF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tlvNre0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_f0feUt3v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JMCy3ciz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EfAe3rAa, HV_BINOP_POW, 1, m, &cBinop_EfAe3rAa_sendMessage);
  cMsg_41JqGMft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_R8ijNSGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xHvDvyNr, HV_BINOP_MULTIPLY, 0, m, &cBinop_xHvDvyNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_p9toqCym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Fk3FGC4m_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Fk3FGC4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9u0WRM9R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_xHvDvyNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5wtf1jY5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AtYgWzEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xHvDvyNr, HV_BINOP_MULTIPLY, 1, m, &cBinop_xHvDvyNr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9u0WRM9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AtYgWzEH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5wtf1jY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qBdHJdgL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qBdHJdgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Xntde1bI_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WSvvMDPA, m);
}

void Heavy_WSTD_DL3Y::cBinop_Xntde1bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fO5dTPqW, m);
}

void Heavy_WSTD_DL3Y::cMsg_f0feUt3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hCeNWLd5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hCeNWLd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vnU1Vbeq, m);
}

void Heavy_WSTD_DL3Y::sEnv_0f4SMEK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RnB0F2Zx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aW09VeCm_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_DrPl9oaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vGqIvczY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_rOsRdteh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_llth9qmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6NZqrXWE, HV_BINOP_POW, 0, m, &cBinop_6NZqrXWE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6NZqrXWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wCm6uEfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4plk0FrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_oFrOM17R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RnB0F2Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O7xptf07_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aW09VeCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DrPl9oaF, 0, m, &cIf_DrPl9oaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O7xptf07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DrPl9oaF, 1, m, &cIf_DrPl9oaF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rOsRdteh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_4plk0FrT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vGqIvczY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_wCm6uEfy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oFrOM17R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6NZqrXWE, HV_BINOP_POW, 1, m, &cBinop_6NZqrXWE_sendMessage);
  cMsg_llth9qmy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_71ph0P71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iD5sxJlI, HV_BINOP_MULTIPLY, 0, m, &cBinop_iD5sxJlI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7H6aFG3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TUEIriqE_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_TUEIriqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e58lqX9u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_iD5sxJlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hM5xpqXu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KUEoFLxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iD5sxJlI, HV_BINOP_MULTIPLY, 1, m, &cBinop_iD5sxJlI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e58lqX9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KUEoFLxL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hM5xpqXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_J7MxMriV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J7MxMriV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wTQBGsvl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Tn44PTZY, m);
}

void Heavy_WSTD_DL3Y::cBinop_wTQBGsvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xk6yv0BX, m);
}

void Heavy_WSTD_DL3Y::cMsg_wCm6uEfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NbU67c0i_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NbU67c0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MkV5Iacq, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vlQ0ZGHH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_59IL3JJF, 0, m, &cSlice_59IL3JJF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LanJ5H3n_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_59IL3JJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_472huHRk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_472huHRk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_yI3FDjQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_472huHRk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_472huHRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iWeTv5Ej_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_XQWJrEvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_12iXedVJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_12iXedVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kOTYomH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_RZjqOCwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RZjqOCwr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XVbRIi0H, 0, m, &cDelay_XVbRIi0H_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RZjqOCwr, 0, m, &cDelay_RZjqOCwr_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JXLLQdQ2, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_XVbRIi0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XVbRIi0H, m);
  cMsg_bL4D71we_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_yRESU812_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0IOz29Is_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_CZFa9JNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nwO3noJ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_G6f7aeBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eGjDhKu3_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_RZjqOCwr, 2, m, &cDelay_RZjqOCwr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QFb2lusb_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nwO3noJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_G6f7aeBB, 0, m, &hTable_G6f7aeBB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kOTYomH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_CZFa9JNP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bL4D71we_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_G6f7aeBB, 0, m, &hTable_G6f7aeBB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QFb2lusb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RZjqOCwr, 0, m, &cDelay_RZjqOCwr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eGjDhKu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_XVbRIi0H, 2, m, &cDelay_XVbRIi0H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0IOz29Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_JXLLQdQ2, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_qXWlE18p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SEEJ8Fns, HV_BINOP_SUBTRACT, 0, m, &cBinop_SEEJ8Fns_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wDRPTOgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OBgVG7sx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_OBgVG7sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gaQbjzoY_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_x8G2Hh9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s1Cd69GK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_R1Zg6NOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_R1Zg6NOg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhCQtDw6, 0, m, &cDelay_UhCQtDw6_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xJH4vOog, 0, m, &sTabread_xJH4vOog_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_UhCQtDw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UhCQtDw6, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xJH4vOog, 0, m, &sTabread_xJH4vOog_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhCQtDw6, 0, m, &cDelay_UhCQtDw6_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_xJH4vOog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iRWvw0Eb, HV_BINOP_SUBTRACT, 0, m, &cBinop_iRWvw0Eb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_uqZ1iRLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lXkUK9wg, HV_BINOP_MAX, 0, m, &cBinop_lXkUK9wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gaQbjzoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uqZ1iRLc, HV_BINOP_MULTIPLY, 0, m, &cBinop_uqZ1iRLc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SEEJ8Fns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IpIYARK9_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_xJH4vOog, 0, m, &sTabread_xJH4vOog_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K1C8GKAi_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hUBzzEGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iRWvw0Eb, HV_BINOP_SUBTRACT, 1, m, &cBinop_iRWvw0Eb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhCQtDw6, 2, m, &cDelay_UhCQtDw6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s1Cd69GK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hUBzzEGL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IpIYARK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1Zg6NOg, 0, m, &cDelay_R1Zg6NOg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UhCQtDw6, 0, m, &cDelay_UhCQtDw6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1XJyQWxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_lXkUK9wg, HV_BINOP_MAX, 1, m, &cBinop_lXkUK9wg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lXkUK9wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SEEJ8Fns, HV_BINOP_SUBTRACT, 1, m, &cBinop_SEEJ8Fns_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_K1C8GKAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1Zg6NOg, 0, m, &cDelay_R1Zg6NOg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4HaJdelw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_R1Zg6NOg, 2, m, &cDelay_R1Zg6NOg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iRWvw0Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4HaJdelw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IaYWLyuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x8G2Hh9l, 0, m, &cVar_x8G2Hh9l_sendMessage);
  cMsg_wDRPTOgo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qXWlE18p, 0, m, &cTabhead_qXWlE18p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CiHWPtHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_P2G8x23X_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_P2G8x23X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HORcmTEl_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_WCF235um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WCF235um, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Btseitex, 0, m, &cDelay_Btseitex_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WCF235um, 0, m, &cDelay_WCF235um_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LO96Zn0Q, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Btseitex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Btseitex, m);
  cMsg_fA9n5NbB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qAzNRF2i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_W369Rg3e_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_rdBwhhYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CnetnIVv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_VqXDdzKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bFV4cD2k_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WCF235um, 2, m, &cDelay_WCF235um_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6MrUKCYK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CnetnIVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_VqXDdzKs, 0, m, &hTable_VqXDdzKs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HORcmTEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_rdBwhhYF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fA9n5NbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_VqXDdzKs, 0, m, &hTable_VqXDdzKs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6MrUKCYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WCF235um, 0, m, &cDelay_WCF235um_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bFV4cD2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Btseitex, 2, m, &cDelay_Btseitex_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_W369Rg3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LO96Zn0Q, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_3pln0vBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VWmPMVp6, HV_BINOP_SUBTRACT, 0, m, &cBinop_VWmPMVp6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pkXMBIa9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GMkUkPQk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_GMkUkPQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_e1hTb0nW_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZC14BOwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iT0tcfO8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_0Xye5bQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0Xye5bQk, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iOzwORbo, 0, m, &cDelay_iOzwORbo_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bb6jcpBr, 0, m, &sTabread_bb6jcpBr_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_iOzwORbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iOzwORbo, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bb6jcpBr, 0, m, &sTabread_bb6jcpBr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iOzwORbo, 0, m, &cDelay_iOzwORbo_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_bb6jcpBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_gdh5tDgN, HV_BINOP_SUBTRACT, 0, m, &cBinop_gdh5tDgN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_wWt8LC0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nEJ4A4E6, HV_BINOP_MAX, 0, m, &cBinop_nEJ4A4E6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e1hTb0nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wWt8LC0c, HV_BINOP_MULTIPLY, 0, m, &cBinop_wWt8LC0c_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VWmPMVp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZSlc9dq8_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_bb6jcpBr, 0, m, &sTabread_bb6jcpBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VRL8Hca5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_cypDUXt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gdh5tDgN, HV_BINOP_SUBTRACT, 1, m, &cBinop_gdh5tDgN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iOzwORbo, 2, m, &cDelay_iOzwORbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iT0tcfO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cypDUXt7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZSlc9dq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Xye5bQk, 0, m, &cDelay_0Xye5bQk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iOzwORbo, 0, m, &cDelay_iOzwORbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_H7ZEgSA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_nEJ4A4E6, HV_BINOP_MAX, 1, m, &cBinop_nEJ4A4E6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nEJ4A4E6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VWmPMVp6, HV_BINOP_SUBTRACT, 1, m, &cBinop_VWmPMVp6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VRL8Hca5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Xye5bQk, 0, m, &cDelay_0Xye5bQk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EwIT4ovT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0Xye5bQk, 2, m, &cDelay_0Xye5bQk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gdh5tDgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EwIT4ovT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lzNjY5Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZC14BOwJ, 0, m, &cVar_ZC14BOwJ_sendMessage);
  cMsg_pkXMBIa9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3pln0vBJ, 0, m, &cTabhead_3pln0vBJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PxxAXlB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CpgWRXLl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZXiq1Zbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DAJBLTqD, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4aSs5GKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gefE6pUA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ThvXzsan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xaaTCYiE, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_n47MCoww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DJFVV6DT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_s7vBg2WS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aveJ4Zj1, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_cnrgeD4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y7LjO1OI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8xAXwhpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EX5eOTSR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_xiBAKdhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MdPO2bfM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p6sOrZDL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_efuieuy3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MdPO2bfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xiBAKdhL, 1, m, &cVar_xiBAKdhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_6CBiguP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FxKZEaJw, 0, m, &cVar_FxKZEaJw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_AC3wq2By_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FxKZEaJw, 0, m, &cVar_FxKZEaJw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_I3DfDTZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AC3wq2By, 0, m, &cIf_AC3wq2By_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_CLpMpKLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6CBiguP2, 0, m, &cIf_6CBiguP2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_a6BnBNzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MsfbDKRr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JNZ6VR5c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rhD5PUQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MsfbDKRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a6BnBNzz, 1, m, &cVar_a6BnBNzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_jgQ1XDPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_MTW3ogoh, 0, m, &cVar_MTW3ogoh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_NoIzcgDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_MTW3ogoh, 0, m, &cVar_MTW3ogoh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_3mcONFon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NoIzcgDu, 0, m, &cIf_NoIzcgDu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KSGdD5qD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jgQ1XDPk, 0, m, &cIf_jgQ1XDPk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DJSxkS4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wMoK7kZV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R185mMJG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QdAlHDab_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wMoK7kZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DJSxkS4W, 1, m, &cVar_DJSxkS4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_5QLoZxWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_SOxiB8GN, 0, m, &cVar_SOxiB8GN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_hXrzVZze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_SOxiB8GN, 0, m, &cVar_SOxiB8GN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lCA77H95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hXrzVZze, 0, m, &cIf_hXrzVZze_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UyGm4Nt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5QLoZxWb, 0, m, &cIf_5QLoZxWb_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_57swfCAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4l7PYbLz, HV_BINOP_DIVIDE, 0, m, &cBinop_4l7PYbLz_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_9sAcgJIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hykyih0Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_Hykyih0Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8Z77tKCc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ht9SZzUL, 0, m, &cSlice_Ht9SZzUL_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ox5GMiPZ, 0, m, &cSlice_ox5GMiPZ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IXbyrClZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yf50s1dg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Ht9SZzUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_Ph8PIg4B, 0, m, &cVar_Ph8PIg4B_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Ph8PIg4B, 0, m, &cVar_Ph8PIg4B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_ox5GMiPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1wB4uRWR, HV_BINOP_NEQ, 1, m, &cBinop_1wB4uRWR_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Ph8PIg4B, 1, m, &cVar_Ph8PIg4B_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_1wB4uRWR, HV_BINOP_NEQ, 1, m, &cBinop_1wB4uRWR_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Ph8PIg4B, 1, m, &cVar_Ph8PIg4B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Ph8PIg4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_eadgGyzv_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_CTJOjTJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YoSXuFny_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MC2XGnsH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_YoSXuFny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1wB4uRWR, HV_BINOP_NEQ, 1, m, &cBinop_1wB4uRWR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MC2XGnsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ph8PIg4B, 0, m, &cVar_Ph8PIg4B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1wB4uRWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CTJOjTJ3, 1, m, &cIf_CTJOjTJ3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yf50s1dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CTJOjTJ3, 0, m, &cIf_CTJOjTJ3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IXbyrClZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1wB4uRWR, HV_BINOP_NEQ, 0, m, &cBinop_1wB4uRWR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JlLuT7l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nGqQZF0T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GZWz86QN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iXZALlBx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ax3mrsMX_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pcBiqeYi_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_22GUUtHz_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m4DfUVw9_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i6ja1S4X_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ueT5b6B9_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5OFXZ5nL_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ePchoBrz_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jm0xwRjw_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_joDek7Wn_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XOmH7PRG_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fYeRDueM_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q5f7ouqm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_Ax3mrsMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LsmoGbuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_pcBiqeYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MpdE3BaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_22GUUtHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GvWIVBWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_m4DfUVw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ii8vzXZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_i6ja1S4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lOlvYVHM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ueT5b6B9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tdhr4qJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5OFXZ5nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5YnwuPvl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ePchoBrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2cMgb3HG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Jm0xwRjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rtza9zpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_joDek7Wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VZi3gM6T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XOmH7PRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AZUGA6B2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_fYeRDueM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uN9EvrYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Q5f7ouqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kmtc64sT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_4l7PYbLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hykyih0Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_Hykyih0Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hykyih0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8Z77tKCc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_GZWz86QN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_57swfCAl, 0, m, &cVar_57swfCAl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9sAcgJIC, 0, m, &cVar_9sAcgJIC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nGqQZF0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4l7PYbLz, HV_BINOP_DIVIDE, 1, m, &cBinop_4l7PYbLz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xT28RqDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9sAcgJIC, 0, m, &cVar_9sAcgJIC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YphCHDQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_57swfCAl, 0, m, &cVar_57swfCAl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LsmoGbuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MpdE3BaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GvWIVBWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3ii8vzXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lOlvYVHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Tdhr4qJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5YnwuPvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2cMgb3HG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rtza9zpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VZi3gM6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AZUGA6B2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uN9EvrYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kmtc64sT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xT28RqDY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YphCHDQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ZtcIXQiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtfPChHB, HV_BINOP_DIVIDE, 0, m, &cBinop_JtfPChHB_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PuxHlg54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EK5doNd5, HV_BINOP_MULTIPLY, 1, m, &cBinop_EK5doNd5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ldsTwjik_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NvROmE2s, 0, m, &cSlice_NvROmE2s_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gF1FlKxl, 0, m, &cSlice_gF1FlKxl_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ent4Ve8D_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ZV56gyj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_NvROmE2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_vRCJKta2, 0, m, &cVar_vRCJKta2_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_vRCJKta2, 0, m, &cVar_vRCJKta2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_gF1FlKxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sFR7fzxC, HV_BINOP_NEQ, 1, m, &cBinop_sFR7fzxC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_vRCJKta2, 1, m, &cVar_vRCJKta2_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sFR7fzxC, HV_BINOP_NEQ, 1, m, &cBinop_sFR7fzxC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_vRCJKta2, 1, m, &cVar_vRCJKta2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_vRCJKta2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_Lb1U0WW0_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_TlKjoT4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QRTJ24r8_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5FquGk7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_v5FquGk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vRCJKta2, 0, m, &cVar_vRCJKta2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QRTJ24r8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sFR7fzxC, HV_BINOP_NEQ, 1, m, &cBinop_sFR7fzxC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sFR7fzxC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TlKjoT4N, 1, m, &cIf_TlKjoT4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ent4Ve8D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sFR7fzxC, HV_BINOP_NEQ, 0, m, &cBinop_sFR7fzxC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5ZV56gyj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TlKjoT4N, 0, m, &cIf_TlKjoT4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8BnTrS62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mw43hBLf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zWzPDE6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Rbi59BgR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QySDJMej_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xRiantbQ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yOY0BD6B_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JnqlOyAc_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PIIONQuF_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DV7iC44o_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AnjHz10d_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vrXLkx6t_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s7ua8zXk_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3DCaYtIG_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oUNh2BB8_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KIl7rFoX_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ioZGIFE0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_QySDJMej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0p26LVUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_xRiantbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ctnkdRO4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_yOY0BD6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IkIYbE0x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JnqlOyAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EtwPOwkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PIIONQuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FKCxeWZT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_DV7iC44o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jKGJla7q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AnjHz10d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4MQVPsUa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vrXLkx6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BwdJZLRA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_s7ua8zXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oxqqZSCQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_3DCaYtIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QAnEDbDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_oUNh2BB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_93vF935e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_KIl7rFoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z8JM3hZO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ioZGIFE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mju8Mc6Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JtfPChHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EK5doNd5, HV_BINOP_MULTIPLY, 0, m, &cBinop_EK5doNd5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EK5doNd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ldsTwjik_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_zWzPDE6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZtcIXQiM, 0, m, &cVar_ZtcIXQiM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PuxHlg54, 0, m, &cVar_PuxHlg54_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Mw43hBLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtfPChHB, HV_BINOP_DIVIDE, 1, m, &cBinop_JtfPChHB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Od07EPNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PuxHlg54, 0, m, &cVar_PuxHlg54_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FqlDBh7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZtcIXQiM, 0, m, &cVar_ZtcIXQiM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0p26LVUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ctnkdRO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IkIYbE0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EtwPOwkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FKCxeWZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jKGJla7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4MQVPsUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BwdJZLRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oxqqZSCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QAnEDbDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_93vF935e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_z8JM3hZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Mju8Mc6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Od07EPNx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FqlDBh7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FBxlZ5Cy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vyk3byPC, HV_BINOP_DIVIDE, 0, m, &cBinop_Vyk3byPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Y830kcCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtsrzKru, HV_BINOP_MULTIPLY, 1, m, &cBinop_GtsrzKru_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8o6CiXbq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_c7ZziEYw, 0, m, &cSlice_c7ZziEYw_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dwKWpcJK, 0, m, &cSlice_dwKWpcJK_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zy0TJ1jt_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6tg5FMXG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_c7ZziEYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_hdSYiuKW, 0, m, &cVar_hdSYiuKW_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hdSYiuKW, 0, m, &cVar_hdSYiuKW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_dwKWpcJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_w7fS9EWq, HV_BINOP_NEQ, 1, m, &cBinop_w7fS9EWq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_hdSYiuKW, 1, m, &cVar_hdSYiuKW_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_w7fS9EWq, HV_BINOP_NEQ, 1, m, &cBinop_w7fS9EWq_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_hdSYiuKW, 1, m, &cVar_hdSYiuKW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_hdSYiuKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_9PZZ5jDB_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_kpW0deOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0w7dzaaO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f0jK6upy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_0w7dzaaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w7fS9EWq, HV_BINOP_NEQ, 1, m, &cBinop_w7fS9EWq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f0jK6upy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hdSYiuKW, 0, m, &cVar_hdSYiuKW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_w7fS9EWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kpW0deOu, 1, m, &cIf_kpW0deOu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Zy0TJ1jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w7fS9EWq, HV_BINOP_NEQ, 0, m, &cBinop_w7fS9EWq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6tg5FMXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kpW0deOu, 0, m, &cIf_kpW0deOu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_UJB5aUF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lEykc8dW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v6eKqjay_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_tAmQ1ihV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LEu60dkr_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qDn2UFLA_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_b7bh0DdU_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aLSkBaAP_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JFD2wiqE_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h9oIqbbh_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PGeLym0D_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QBxUDJX2_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2zkPRW5L_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RvQ6bXXl_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASBaL0L3_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ISNn266v_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GinCIFLa_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_LEu60dkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gGXJJkKU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qDn2UFLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SK9SPPst_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_b7bh0DdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0g5yNWAN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aLSkBaAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F3aJ08cN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_JFD2wiqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rZQOqedL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_h9oIqbbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X156yWda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PGeLym0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P2T4cPMC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QBxUDJX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LDEEYBbV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_2zkPRW5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fOIeZ95D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RvQ6bXXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0uxCTVpa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ASBaL0L3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aeGlIgzY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ISNn266v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_glVRXGNj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_GinCIFLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oFijTHRE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Vyk3byPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GtsrzKru, HV_BINOP_MULTIPLY, 0, m, &cBinop_GtsrzKru_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GtsrzKru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8o6CiXbq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_v6eKqjay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FBxlZ5Cy, 0, m, &cVar_FBxlZ5Cy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y830kcCq, 0, m, &cVar_Y830kcCq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lEykc8dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vyk3byPC, HV_BINOP_DIVIDE, 1, m, &cBinop_Vyk3byPC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fad1w80s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FBxlZ5Cy, 0, m, &cVar_FBxlZ5Cy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Op4TjY1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y830kcCq, 0, m, &cVar_Y830kcCq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gGXJJkKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SK9SPPst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0g5yNWAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F3aJ08cN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rZQOqedL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X156yWda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P2T4cPMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LDEEYBbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fOIeZ95D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0uxCTVpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aeGlIgzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_glVRXGNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oFijTHRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Op4TjY1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fad1w80s_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rQt4NqOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8nV48HJr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ezjVHXyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Q16uaZlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8nV48HJr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ezjVHXyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lWJPq67V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8nV48HJr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ezjVHXyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wug8Ng79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8nV48HJr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ezjVHXyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vIJAZNY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_8nV48HJr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ezjVHXyI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DUwW9ZT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_hSRcDpZG, 0, m, &cVar_hSRcDpZG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1J8xQsIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_C0DcBSow, 0, m, &cVar_C0DcBSow_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uLKVU2DG, 0, m, &cVar_uLKVU2DG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LbQ7P5d6, 0, m, &cVar_LbQ7P5d6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TFEQ9ShN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DpRyDrpP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HEzCRziz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DpRyDrpP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_7HGal3lX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cSlNmWNZ, 0, m, &cVar_cSlNmWNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ThrhcJSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mFyE8y3s, 0, m, &cVar_mFyE8y3s_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O8TCmHl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TABzL5ZJ, 0, m, &cVar_TABzL5ZJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Szm8LVpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DpRyDrpP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8YDivj8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_DpRyDrpP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_PZK9cMuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XsExLYiq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nH2mXYLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XsExLYiq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_x9N2oztG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_m0iZefOe, 0, m, &cVar_m0iZefOe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7v7I58r6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7NfHwQ3h, 0, m, &cVar_7NfHwQ3h_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fnKkeefa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VdM4AORz, 0, m, &cVar_VdM4AORz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_c6zXn8Mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XsExLYiq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ldbhzzoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_XsExLYiq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_80fpigAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7QCf5aRj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_b2F8Fpt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7QCf5aRj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_9B2q3QqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ecEMUUNV, 0, m, &cVar_ecEMUUNV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SUAmSh0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YRLRlpmK, 0, m, &cVar_YRLRlpmK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gKvcmsA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mx6pdwcA, 0, m, &cVar_Mx6pdwcA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uztMDHvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7QCf5aRj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6QqxDJsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7QCf5aRj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_eadgGyzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CLpMpKLc, 0, m, &cVar_CLpMpKLc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_efuieuy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KTq4QIl5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AQcMfrkz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p6sOrZDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uaxNPmYX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cyjkw5m4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cyjkw5m4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I3DfDTZT, 0, m, &cVar_I3DfDTZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uaxNPmYX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AC3wq2By, 1, m, &cIf_AC3wq2By_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KTq4QIl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6CBiguP2, 1, m, &cIf_6CBiguP2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AQcMfrkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CLpMpKLc, 0, m, &cVar_CLpMpKLc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lb1U0WW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KSGdD5qD, 0, m, &cVar_KSGdD5qD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rhD5PUQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pdczje2i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A35v7Spn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JNZ6VR5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NKaBGJae_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xIrySPyq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xIrySPyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3mcONFon, 0, m, &cVar_3mcONFon_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NKaBGJae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NoIzcgDu, 1, m, &cIf_NoIzcgDu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pdczje2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jgQ1XDPk, 1, m, &cIf_jgQ1XDPk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A35v7Spn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KSGdD5qD, 0, m, &cVar_KSGdD5qD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9PZZ5jDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UyGm4Nt6, 0, m, &cVar_UyGm4Nt6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QdAlHDab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6pVLHIfv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VsKe620K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_R185mMJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nq9AqSjT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DKDOQbMz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Nq9AqSjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hXrzVZze, 1, m, &cIf_hXrzVZze_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DKDOQbMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lCA77H95, 0, m, &cVar_lCA77H95_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VsKe620K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UyGm4Nt6, 0, m, &cVar_UyGm4Nt6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6pVLHIfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5QLoZxWb, 1, m, &cIf_5QLoZxWb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_udUbLD2F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C0DcBSow, 0, m, &cVar_C0DcBSow_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YJgxefG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uLKVU2DG, 0, m, &cVar_uLKVU2DG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TuXzVDve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LbQ7P5d6, 0, m, &cVar_LbQ7P5d6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KaiVidYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XgDvdedK, 0, m, &cVar_XgDvdedK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZJ1hffs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UJjvdhri_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NT9L13Tu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FNsbLg4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F99zfszB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CG0bXJbr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F6oDhYtt_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gaCgzBFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YZb3cpoT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g1b4cn9B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tu9lUGkk_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KPP9Xphw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SCTOYFWw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F0FKOkVG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OGVvxAzn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OK95eVkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hzrhbynj_sendMessage(_c, 0, m);
  cMsg_aGiPp1Ha_sendMessage(_c, 0, m);
  cMsg_4SZY5IsU_sendMessage(_c, 0, m);
  cMsg_mn51Fk8B_sendMessage(_c, 0, m);
  cMsg_u0n6Hdcn_sendMessage(_c, 0, m);
  cMsg_h3OCYCSX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tKJyyV7n, 0, m, &cVar_tKJyyV7n_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XgDvdedK, 0, m, &cVar_XgDvdedK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nKV3VcRg, 0, m, &cVar_nKV3VcRg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MtWe9rhZ, 0, m, &cVar_MtWe9rhZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_opwa3kVl, 0, m, &cVar_opwa3kVl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eCbJiEmn, 0, m, &cVar_eCbJiEmn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4YRJbCzH, 0, m, &cVar_4YRJbCzH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vmc5wlcm, 0, m, &cVar_vmc5wlcm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YUz7bndj, 0, m, &cVar_YUz7bndj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TKf7wzxp, 0, m, &cVar_TKf7wzxp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nC9B0eue, 0, m, &cVar_nC9B0eue_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rTZIdtzE, 0, m, &cVar_rTZIdtzE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JnjGSftv, 0, m, &cVar_JnjGSftv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wUvWmhak, 0, m, &cVar_wUvWmhak_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zbeLt9MQ, 0, m, &cVar_zbeLt9MQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZH3mvOl6, 0, m, &cVar_ZH3mvOl6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E3t3wJ69, 0, m, &cVar_E3t3wJ69_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hjdgief4, 0, m, &cVar_hjdgief4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WYaVSJZJ, 0, m, &cVar_WYaVSJZJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k4l5hAQf, 0, m, &cVar_k4l5hAQf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wx5RiGQ8, 0, m, &cVar_wx5RiGQ8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8oSTuWTx, 0, m, &cVar_8oSTuWTx_sendMessage);
  cMsg_88cCTdue_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_8hOp9xqw, 0, m, &cVar_8hOp9xqw_sendMessage);
  cMsg_ImbtyxW9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ddNAi7O6, 0, m, &cVar_ddNAi7O6_sendMessage);
  cMsg_EOmnoCVM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DnEgOjpa, 0, m, &cVar_DnEgOjpa_sendMessage);
  cMsg_VMSHKzSM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_17aBEsbG, 0, m, &cVar_17aBEsbG_sendMessage);
  cMsg_p9toqCym_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_R8ijNSGF, 0, m, &cVar_R8ijNSGF_sendMessage);
  cMsg_7H6aFG3g_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_71ph0P71, 0, m, &cVar_71ph0P71_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B3gSS8LD, 0, m, &cVar_B3gSS8LD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D70C9Ciw, 0, m, &cVar_D70C9Ciw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fc0jQ8vp, 0, m, &cVar_fc0jQ8vp_sendMessage);
  cMsg_XasV9fkZ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tzOVxEew, 0, m, &cVar_tzOVxEew_sendMessage);
  cMsg_6H4vskO8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_W3nVsx9n, 0, m, &cVar_W3nVsx9n_sendMessage);
  cMsg_F9GDNL0m_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rezjnfAt, 0, m, &cVar_rezjnfAt_sendMessage);
  cMsg_U1dWRQCu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_I4DDkla0, 0, m, &cVar_I4DDkla0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jW2QKe1t, 0, m, &cVar_jW2QKe1t_sendMessage);
  cMsg_irsuZkGD_sendMessage(_c, 0, m);
  cMsg_XWViuADO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_274n9S7T, 0, m, &cVar_274n9S7T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iWxVhMIJ, 0, m, &cVar_iWxVhMIJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DiQ3Qca1, 0, m, &cVar_DiQ3Qca1_sendMessage);
  cMsg_eeAc8Xkm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gSD8t8XO, 0, m, &cVar_gSD8t8XO_sendMessage);
  cMsg_Vdjyg4Bd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fpxTmhQB, 0, m, &cVar_fpxTmhQB_sendMessage);
  cMsg_YTnto1OY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WunJiGUG, 0, m, &cVar_WunJiGUG_sendMessage);
  cMsg_Dq1Xq0py_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PBay6eda, 0, m, &cVar_PBay6eda_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zFlf2zdf, 0, m, &cVar_zFlf2zdf_sendMessage);
  cMsg_G25uFVtF_sendMessage(_c, 0, m);
  cMsg_HAkdRTZB_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dleIlgbh, 0, m, &cVar_dleIlgbh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bJrmdpAL, 0, m, &cVar_bJrmdpAL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o7ARrhsv, 0, m, &cVar_o7ARrhsv_sendMessage);
  cMsg_g5V4DEXO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Do1AHElv, 0, m, &cVar_Do1AHElv_sendMessage);
  cMsg_CyyW3mhH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1R6WlJjl, 0, m, &cVar_1R6WlJjl_sendMessage);
  cMsg_HYf4tnuo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lAJr7jSD, 0, m, &cVar_lAJr7jSD_sendMessage);
  cMsg_CbmpL6it_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MJPhbEM7, 0, m, &cVar_MJPhbEM7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yI3FDjQ2, 0, m, &cVar_yI3FDjQ2_sendMessage);
  cMsg_XQWJrEvI_sendMessage(_c, 0, m);
  cMsg_CiHWPtHD_sendMessage(_c, 0, m);
  cMsg_1J8xQsIF_sendMessage(_c, 0, m);
  cMsg_DUwW9ZT3_sendMessage(_c, 0, m);
  cMsg_hoxXKhgj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iS1RJB7L, 0, m, &cVar_iS1RJB7L_sendMessage);
  cMsg_t6EGukW3_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_F4GtTbIr, 0, m, &cTabhead_F4GtTbIr_sendMessage);
  cMsg_jkkZyCTD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Uwarmot4, 0, m, &cVar_Uwarmot4_sendMessage);
  cMsg_Wen2Bi8G_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_kauJ8r1J, 0, m, &cTabhead_kauJ8r1J_sendMessage);
  cMsg_gMjPKmUv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zgdgXT1x, 0, m, &cVar_zgdgXT1x_sendMessage);
  cMsg_sYQJUFEF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_dneQWYhC, 0, m, &cTabhead_dneQWYhC_sendMessage);
  cMsg_Sn9oUhLA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xpGSKRxr, 0, m, &cVar_xpGSKRxr_sendMessage);
  cMsg_JR2KJ18h_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OyhPKcdz, 0, m, &cTabhead_OyhPKcdz_sendMessage);
  cMsg_1XJyQWxk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_x8G2Hh9l, 0, m, &cVar_x8G2Hh9l_sendMessage);
  cMsg_wDRPTOgo_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qXWlE18p, 0, m, &cTabhead_qXWlE18p_sendMessage);
  cMsg_H7ZEgSA6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZC14BOwJ, 0, m, &cVar_ZC14BOwJ_sendMessage);
  cMsg_pkXMBIa9_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_3pln0vBJ, 0, m, &cTabhead_3pln0vBJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UkfaOgXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YxsMxdHT, HV_BINOP_MULTIPLY, 0, m, &cBinop_YxsMxdHT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NVKxyP2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eq3p7sj6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VkkuSbME_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ey5zp2KC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_CdPLf4Bl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jzpHmyMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UPqJhmW6_sendMessage);
  cMsg_IkxZA6BJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_OG2oqp04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNHE70Or, HV_BINOP_MULTIPLY, 0, m, &cBinop_sNHE70Or_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_K4TOxKd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LqXecq8o_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4nv2tkmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_13f7rft3, HV_BINOP_MULTIPLY, 1, m, &cBinop_13f7rft3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FBZYySG7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PlXK60o2_sendMessage);
  cMsg_MIkJmXMy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_k6dH5fXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rbIP2cb2, HV_BINOP_MULTIPLY, 0, m, &cBinop_rbIP2cb2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nziBQju7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qy0ZPVr6_sendMessage(_c, 0, m);
  cMsg_aYAA5vQW_sendMessage(_c, 0, m);
  cMsg_7fNZnBr7_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_R4RPfyqL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_70uR3XUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_z7IRpRJC_sendMessage);
  cMsg_HBPQdLTS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_2hFLgozJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_opwa3kVl, 0, m, &cVar_opwa3kVl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FzXIJSMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u96ooQPM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZoghP7mU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xHQ9pm7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_043paqo0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RxKbb7Cp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ftbVo9LI_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_edXfK5lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fz2eFrWZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ITrykwMa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gtzx4T6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pH6TlMzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rR9FZq3R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uTRcTZbB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1WMwaSVu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FNmEHAgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VoPqS4fM, HV_BINOP_MULTIPLY, 0, m, &cBinop_VoPqS4fM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cRvsu54X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bdY6HmkI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P7YqiTqm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dEmrN7Vu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_WOo33RPO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SJgIOV4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_P53x4Gar_sendMessage);
  cMsg_4EksZOnh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_O6rWZGEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CcHBnVmp, HV_BINOP_MULTIPLY, 0, m, &cBinop_CcHBnVmp_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_P27XG5Og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_A4cuIrfh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FveH3am0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MBZmrFIS, HV_BINOP_MULTIPLY, 1, m, &cBinop_MBZmrFIS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_O1RVdYs7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7MlvmTjd_sendMessage);
  cMsg_1gZhsmdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_VV7w97yK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nQx4FhwP, HV_BINOP_MULTIPLY, 0, m, &cBinop_nQx4FhwP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PA49Fwzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VwmOgF5F_sendMessage(_c, 0, m);
  cMsg_jubqkVgJ_sendMessage(_c, 0, m);
  cMsg_pIGbx2Cy_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_FiIEFwzC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jl2F20Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bixzS0Ki_sendMessage);
  cMsg_vYuPEsdN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_4PFlWFeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hSRcDpZG, 0, m, &cVar_hSRcDpZG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sMoqqg5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7HGal3lX_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8vPfhSEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ThrhcJSY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iINKZIfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_O8TCmHl2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kslNsfMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_x9N2oztG_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TUQ1VOlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_7v7I58r6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0FLxji4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_9B2q3QqC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aKM34gtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_SUAmSh0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Kc4ymUDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gKvcmsA5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1hEm6m01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_fnKkeefa_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zphpTjim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pbsmgdOr, HV_BINOP_MULTIPLY, 1, m, &cBinop_pbsmgdOr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4sFRyR5S_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_izPin5kW, HV_BINOP_MULTIPLY, 1, m, &cBinop_izPin5kW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TVYQW88U_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Xyn50kgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_19VdkH0V, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_I0DqX5Ua, m);
}

void Heavy_WSTD_DL3Y::cReceive_dtbg7JaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5spBtde2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wHvued1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QM9cy4Fo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OK3WIORE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rdF1B6xJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_rdF1B6xJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkxI985e_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_beuJeVO9, HV_BINOP_MULTIPLY, 1, m, &cBinop_beuJeVO9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sDC5rdeh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_KGh0Llek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Nz5NOcqJ, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_G2K3Tots, m);
}

void Heavy_WSTD_DL3Y::cReceive_W0JlXdxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Zgkot3rz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hLfnkFAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_tr50wPsU_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QgiHht3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uqZ1iRLc, HV_BINOP_MULTIPLY, 1, m, &cBinop_uqZ1iRLc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IaYWLyuf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wWt8LC0c, HV_BINOP_MULTIPLY, 1, m, &cBinop_wWt8LC0c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lzNjY5Nl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_iWeTv5Ej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RK7mYsxZ, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CGDnSy6q, m);
}

void Heavy_WSTD_DL3Y::cReceive_DktlemJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kf2LvhES_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kCZB0hcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_a7bSQaAJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_46oO5Ee0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I3DfDTZT, 0, m, &cVar_I3DfDTZT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_IVnUSJ6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xiBAKdhL, 0, m, &cVar_xiBAKdhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_l99pvkhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a6BnBNzz, 0, m, &cVar_a6BnBNzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_qBtf0Knx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3mcONFon, 0, m, &cVar_3mcONFon_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_mk9GcxLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lCA77H95, 0, m, &cVar_lCA77H95_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_cWk7AOZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DJSxkS4W, 0, m, &cVar_DJSxkS4W_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bgWhw8ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JlLuT7l9, 0, m, &cVar_JlLuT7l9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8BnTrS62, 0, m, &cVar_8BnTrS62_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UJB5aUF2, 0, m, &cVar_UJB5aUF2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_8VuGocOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Rbi59BgR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_XIn4OsEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iXZALlBx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_qeKyqvfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tAmQ1ihV_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_omA5KCpe, VOf(Bf0));
    __hv_line_f(&sLine_q55rIIQu, VOf(Bf1));
    __hv_line_f(&sLine_RXuwQDqx, VOf(Bf2));
    __hv_line_f(&sLine_U43hhlwT, VOf(Bf3));
    __hv_line_f(&sLine_XNI4RVFg, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_oRlDI940, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_mVbmpBku, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_3BRyh3aq, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_zFY4KbZe, VOf(Bf1));
    __hv_line_f(&sLine_jcGwNiJH, VOf(Bf0));
    __hv_line_f(&sLine_32jhpGSq, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_T3t9qKX4, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_81DZFLqG, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_AYuQ1App, VOf(Bf5));
    __hv_line_f(&sLine_8RhhWQvf, VOf(Bf1));
    __hv_line_f(&sLine_LaHhP2Z2, VOf(Bf2));
    __hv_line_f(&sLine_VhlTNYj1, VOf(Bf4));
    __hv_line_f(&sLine_RWVVlYj2, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_NC2UYpbC, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_61nm4BUS, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_F0ko72bF, VOf(Bf6));
    __hv_line_f(&sLine_8IJ9l0fM, VOf(Bf2));
    __hv_line_f(&sLine_hNvBSVUl, VOf(Bf1));
    __hv_line_f(&sLine_OroIV9lu, VOf(Bf5));
    __hv_line_f(&sLine_8ZdQz8YU, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_a0EBFV1X, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_uhrbE4A6, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_wDNEl99D, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_9xMHmRlp, VOf(Bf2));
    __hv_line_f(&sLine_1n3h4wAe, VOf(Bf6));
    __hv_line_f(&sLine_nkFvphH8, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_Pv6tt6Rf, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_0C0Hnj1D, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_HgcRTfkJ, VOf(Bf8));
    __hv_line_f(&sLine_eyntfMig, VOf(Bf2));
    __hv_line_f(&sLine_M2nAZxzn, VOf(Bf1));
    __hv_line_f(&sLine_yiFINTHQ, VOf(Bf7));
    __hv_line_f(&sLine_fRKVhMgZ, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_uP1Enq5k, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_a6VLjl42, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_Qca1B6tO, VOf(Bf9));
    __hv_tabread_f(&sTabread_cDDUNJrW, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Ld81jzZc, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_SJhBnlC3, VOf(Bf9));
    __hv_tabread_f(&sTabread_XSVARinO, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_T967aA45, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_cOsg6KrM, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_gXg8aEzO, VOf(Bf3));
    __hv_rpole_f(&sRPole_9SGRvcpm, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_r6WN5A7I, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FdrK9cjG, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_VrlnEtB7, VIf(Bf3));
    __hv_varread_f(&sVarf_iHQL8um3, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_XbliOmNJ, VOf(Bf5));
    __hv_rpole_f(&sRPole_PAhqg6mO, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_EoEdRl1c, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_ij7U779I, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_UipxQ9Q2, VIf(Bf5));
    __hv_varread_f(&sVarf_19VdkH0V, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_dcvx6aMT, VOf(Bf1));
    __hv_varread_f(&sVarf_I0DqX5Ua, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_yohbZYcF, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_1fhR3Fi8, VOf(Bf1));
    __hv_varread_f(&sVarf_c5GKq47s, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_MrllREA8, VOf(Bf1));
    __hv_rpole_f(&sRPole_2Mwdk09a, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_3NM8vyFY, VIf(Bf8), &sEnv_3NM8vyFY_sendMessage);
    __hv_varread_f(&sVarf_GwQwkNMg, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_qm81l0ZA, VOf(Bf1));
    __hv_rpole_f(&sRPole_VJkyzgxk, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_cOsg6KrM, VIf(Bf1));
    __hv_line_f(&sLine_HSonlW4E, VOf(Bf1));
    __hv_line_f(&sLine_DKrV1FLI, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_2vs4YYz0, VOf(Bf1));
    __hv_varread_f(&sVarf_Kc4xE38x, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_64sZ3ziu, VOf(Bf1));
    __hv_rpole_f(&sRPole_xDfdw80J, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_3Ur5xe5Q, VIf(Bf8), &sEnv_3Ur5xe5Q_sendMessage);
    __hv_varread_f(&sVarf_XDmyN7U0, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ETdThg09, VOf(Bf1));
    __hv_rpole_f(&sRPole_7iXdq632, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_iHQL8um3, VIf(Bf1));
    __hv_varwrite_f(&sVarf_ZxFvLpXk, VIf(Bf2));
    __hv_varread_f(&sVarf_cigMSjpS, VOf(Bf2));
    __hv_varread_f(&sVarf_rGjQCoTH, VOf(Bf1));
    __hv_line_f(&sLine_NqvJu6LU, VOf(Bf8));
    __hv_tabread_f(&sTabread_CX3DdD67, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_1iWzq5fB, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_702bVxoo, VOf(Bf8));
    __hv_tabread_f(&sTabread_I5GDdxiY, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_WRbfQt8y, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_o6EklrDZ, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_Hl2VWnF0, VOf(Bf2));
    __hv_rpole_f(&sRPole_b2swAmbm, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_pbAyNHyP, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_6KXxTGnk, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_72VoPxid, VIf(Bf2));
    __hv_varread_f(&sVarf_RKwwVbn7, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_KhRYLDTl, VOf(Bf1));
    __hv_rpole_f(&sRPole_lHbncL31, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_sWxa3gO1, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_pr06Jslp, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_tcC5eXT9, VIf(Bf1));
    __hv_varread_f(&sVarf_Nz5NOcqJ, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_KTRiXuvp, VOf(Bf3));
    __hv_varread_f(&sVarf_G2K3Tots, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_lyaalCbg, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_NeLd2ecQ, VOf(Bf3));
    __hv_varread_f(&sVarf_yHhqifyN, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_FbS1wYDV, VOf(Bf3));
    __hv_rpole_f(&sRPole_DFTmD5KJ, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_exOBYnSR, VIf(Bf9), &sEnv_exOBYnSR_sendMessage);
    __hv_varread_f(&sVarf_gYAC76SU, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_viTTaNIf, VOf(Bf3));
    __hv_rpole_f(&sRPole_wS3gwc26, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_o6EklrDZ, VIf(Bf3));
    __hv_line_f(&sLine_KK3vuWZW, VOf(Bf3));
    __hv_line_f(&sLine_GRLPEUIu, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_7cr0nyxy, VOf(Bf3));
    __hv_varread_f(&sVarf_0IHZNvvW, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_omidDxOV, VOf(Bf3));
    __hv_rpole_f(&sRPole_OBg8S9Rj, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_ZZdJf1AB, VIf(Bf9), &sEnv_ZZdJf1AB_sendMessage);
    __hv_varread_f(&sVarf_Kv7rY4Hf, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_DT1rW6L0, VOf(Bf3));
    __hv_rpole_f(&sRPole_8iAI62Kh, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_RKwwVbn7, VIf(Bf3));
    __hv_varwrite_f(&sVarf_iQaL2WTC, VIf(Bf5));
    __hv_varread_f(&sVarf_dYXvFRNE, VOf(Bf5));
    __hv_varread_f(&sVarf_aKqpr7ve, VOf(Bf3));
    __hv_line_f(&sLine_DAJBLTqD, VOf(Bf9));
    __hv_tabread_f(&sTabread_xJH4vOog, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_CpgWRXLl, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_gefE6pUA, VOf(Bf9));
    __hv_tabread_f(&sTabread_bb6jcpBr, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_xaaTCYiE, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_kENnCArN, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_JGXmGjsr, VOf(Bf5));
    __hv_rpole_f(&sRPole_pizf7C07, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_rkWnf1Jn, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FqBwC6vH, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_JXLLQdQ2, VIf(Bf5));
    __hv_varread_f(&sVarf_8U1S45Bk, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_HHgyGoGd, VOf(Bf3));
    __hv_rpole_f(&sRPole_WFjHfnZo, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_4YrkIPHW, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_skYCdhEk, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_LO96Zn0Q, VIf(Bf3));
    __hv_varread_f(&sVarf_RK7mYsxZ, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_aveJ4Zj1, VOf(Bf2));
    __hv_varread_f(&sVarf_CGDnSy6q, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_DJFVV6DT, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_vnU1Vbeq, VOf(Bf2));
    __hv_varread_f(&sVarf_WSvvMDPA, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_fO5dTPqW, VOf(Bf2));
    __hv_rpole_f(&sRPole_mfiopNmy, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_3J942x7F, VIf(Bf8), &sEnv_3J942x7F_sendMessage);
    __hv_varread_f(&sVarf_Fa84xRqF, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_DzTf67KN, VOf(Bf2));
    __hv_rpole_f(&sRPole_ICzgsh0f, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_kENnCArN, VIf(Bf2));
    __hv_line_f(&sLine_EX5eOTSR, VOf(Bf2));
    __hv_line_f(&sLine_Y7LjO1OI, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_MkV5Iacq, VOf(Bf2));
    __hv_varread_f(&sVarf_Tn44PTZY, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_xk6yv0BX, VOf(Bf2));
    __hv_rpole_f(&sRPole_gdwOm5GA, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_0f4SMEK6, VIf(Bf8), &sEnv_0f4SMEK6_sendMessage);
    __hv_varread_f(&sVarf_EAbArrXN, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_YqLtNHxp, VOf(Bf2));
    __hv_rpole_f(&sRPole_8PStfZAP, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_8U1S45Bk, VIf(Bf2));
    __hv_varwrite_f(&sVarf_OmNj7kHk, VIf(Bf1));
    __hv_varwrite_f(&sVarf_G3TknXFq, VIf(Bf10));
    __hv_varwrite_f(&sVarf_VB4p1ilO, VIf(Bf11));
    __hv_varwrite_f(&sVarf_UiPtzDXG, VIf(Bf12));
    __hv_varwrite_f(&sVarf_cigMSjpS, VIf(Bf0));
    __hv_varwrite_f(&sVarf_rGjQCoTH, VIf(Bf6));
    __hv_varwrite_f(&sVarf_dYXvFRNE, VIf(Bf4));
    __hv_varwrite_f(&sVarf_aKqpr7ve, VIf(Bf7));
    __hv_varread_f(&sVarf_G3TknXFq, VOf(Bf7));
    __hv_varread_f(&sVarf_VB4p1ilO, VOf(Bf4));
    __hv_varread_f(&sVarf_UiPtzDXG, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_ZxFvLpXk, VOf(Bf6));
    __hv_varread_f(&sVarf_iQaL2WTC, VOf(Bf7));
    __hv_varread_f(&sVarf_OmNj7kHk, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
